@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'ListBoxControl.h'
+** Meta object code from reading C++ file 'moc-ListBoxControl.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/ListBoxControl.h"
+#include "libgui/graphics/moc-ListBoxControl.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'ListBoxControl.h' doesn't include <QObject>."
+#error "The header file 'moc-ListBoxControl.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -23,32 +23,31 @@
 QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
-struct qt_meta_stringdata_QtHandles__ListBoxControl_t {
+struct qt_meta_stringdata_octave__ListBoxControl_t {
     QByteArrayData data[6];
-    char stringdata0[91];
+    char stringdata0[88];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
-    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__ListBoxControl_t, stringdata0) + ofs \
+    qptrdiff(offsetof(qt_meta_stringdata_octave__ListBoxControl_t, stringdata0) + ofs \
         - idx * sizeof(QByteArrayData)) \
     )
-static const qt_meta_stringdata_QtHandles__ListBoxControl_t qt_meta_stringdata_QtHandles__ListBoxControl = {
+static const qt_meta_stringdata_octave__ListBoxControl_t qt_meta_stringdata_octave__ListBoxControl = {
     {
-QT_MOC_LITERAL(0, 0, 25), // "QtHandles::ListBoxControl"
-QT_MOC_LITERAL(1, 26, 20), // "itemSelectionChanged"
-QT_MOC_LITERAL(2, 47, 0), // ""
-QT_MOC_LITERAL(3, 48, 13), // "itemActivated"
-QT_MOC_LITERAL(4, 62, 11), // "itemPressed"
-QT_MOC_LITERAL(5, 74, 16) // "QListWidgetItem*"
+QT_MOC_LITERAL(0, 0, 22), // "octave::ListBoxControl"
+QT_MOC_LITERAL(1, 23, 20), // "itemSelectionChanged"
+QT_MOC_LITERAL(2, 44, 0), // ""
+QT_MOC_LITERAL(3, 45, 13), // "itemActivated"
+QT_MOC_LITERAL(4, 59, 11), // "itemPressed"
+QT_MOC_LITERAL(5, 71, 16) // "QListWidgetItem*"
 
     },
-    "QtHandles::ListBoxControl\0"
-    "itemSelectionChanged\0\0itemActivated\0"
-    "itemPressed\0QListWidgetItem*"
+    "octave::ListBoxControl\0itemSelectionChanged\0"
+    "\0itemActivated\0itemPressed\0QListWidgetItem*"
 };
 #undef QT_MOC_LITERAL
 
-static const uint qt_meta_data_QtHandles__ListBoxControl[] = {
+static const uint qt_meta_data_octave__ListBoxControl[] = {
 
  // content:
        7,       // revision
@@ -74,7 +73,7 @@ static const uint qt_meta_data_QtHandles__ListBoxControl[] = {
        0        // eod
 };
 
-void QtHandles::ListBoxControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+void octave::ListBoxControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
         ListBoxControl *_t = static_cast<ListBoxControl *>(_o);
@@ -88,26 +87,26 @@ void QtHandles::ListBoxControl::qt_static_metacall(QObject *_o, QMetaObject::Cal
     }
 }
 
-const QMetaObject QtHandles::ListBoxControl::staticMetaObject = {
-    { &BaseControl::staticMetaObject, qt_meta_stringdata_QtHandles__ListBoxControl.data,
-      qt_meta_data_QtHandles__ListBoxControl,  qt_static_metacall, nullptr, nullptr}
+const QMetaObject octave::ListBoxControl::staticMetaObject = {
+    { &BaseControl::staticMetaObject, qt_meta_stringdata_octave__ListBoxControl.data,
+      qt_meta_data_octave__ListBoxControl,  qt_static_metacall, nullptr, nullptr}
 };
 
 
-const QMetaObject *QtHandles::ListBoxControl::metaObject() const
+const QMetaObject *octave::ListBoxControl::metaObject() const
 {
     return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
-void *QtHandles::ListBoxControl::qt_metacast(const char *_clname)
+void *octave::ListBoxControl::qt_metacast(const char *_clname)
 {
     if (!_clname) return nullptr;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ListBoxControl.stringdata0))
+    if (!strcmp(_clname, qt_meta_stringdata_octave__ListBoxControl.stringdata0))
         return static_cast<void*>(this);
     return BaseControl::qt_metacast(_clname);
 }
 
-int QtHandles::ListBoxControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+int octave::ListBoxControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = BaseControl::qt_metacall(_c, _id, _a);
     if (_id < 0)
