@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'SliderControl.h'
+** Meta object code from reading C++ file 'moc-SliderControl.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/graphics/SliderControl.h"
+#include "libgui/graphics/moc-SliderControl.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'SliderControl.h' doesn't include <QObject>."
+#error "The header file 'moc-SliderControl.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -23,29 +23,29 @@
 QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
-struct qt_meta_stringdata_QtHandles__SliderControl_t {
+struct qt_meta_stringdata_octave__SliderControl_t {
     QByteArrayData data[4];
-    char stringdata0[44];
+    char stringdata0[41];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
-    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__SliderControl_t, stringdata0) + ofs \
+    qptrdiff(offsetof(qt_meta_stringdata_octave__SliderControl_t, stringdata0) + ofs \
         - idx * sizeof(QByteArrayData)) \
     )
-static const qt_meta_stringdata_QtHandles__SliderControl_t qt_meta_stringdata_QtHandles__SliderControl = {
+static const qt_meta_stringdata_octave__SliderControl_t qt_meta_stringdata_octave__SliderControl = {
     {
-QT_MOC_LITERAL(0, 0, 24), // "QtHandles::SliderControl"
-QT_MOC_LITERAL(1, 25, 12), // "valueChanged"
-QT_MOC_LITERAL(2, 38, 0), // ""
-QT_MOC_LITERAL(3, 39, 4) // "ival"
+QT_MOC_LITERAL(0, 0, 21), // "octave::SliderControl"
+QT_MOC_LITERAL(1, 22, 12), // "valueChanged"
+QT_MOC_LITERAL(2, 35, 0), // ""
+QT_MOC_LITERAL(3, 36, 4) // "ival"
 
     },
-    "QtHandles::SliderControl\0valueChanged\0"
-    "\0ival"
+    "octave::SliderControl\0valueChanged\0\0"
+    "ival"
 };
 #undef QT_MOC_LITERAL
 
-static const uint qt_meta_data_QtHandles__SliderControl[] = {
+static const uint qt_meta_data_octave__SliderControl[] = {
 
  // content:
        7,       // revision
@@ -67,7 +67,7 @@ static const uint qt_meta_data_QtHandles__SliderControl[] = {
        0        // eod
 };
 
-void QtHandles::SliderControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+void octave::SliderControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
         SliderControl *_t = static_cast<SliderControl *>(_o);
@@ -79,26 +79,26 @@ void QtHandles::SliderControl::qt_static_metacall(QObject *_o, QMetaObject::Call
     }
 }
 
-const QMetaObject QtHandles::SliderControl::staticMetaObject = {
-    { &BaseControl::staticMetaObject, qt_meta_stringdata_QtHandles__SliderControl.data,
-      qt_meta_data_QtHandles__SliderControl,  qt_static_metacall, nullptr, nullptr}
+const QMetaObject octave::SliderControl::staticMetaObject = {
+    { &BaseControl::staticMetaObject, qt_meta_stringdata_octave__SliderControl.data,
+      qt_meta_data_octave__SliderControl,  qt_static_metacall, nullptr, nullptr}
 };
 
 
-const QMetaObject *QtHandles::SliderControl::metaObject() const
+const QMetaObject *octave::SliderControl::metaObject() const
 {
     return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
-void *QtHandles::SliderControl::qt_metacast(const char *_clname)
+void *octave::SliderControl::qt_metacast(const char *_clname)
 {
     if (!_clname) return nullptr;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__SliderControl.stringdata0))
+    if (!strcmp(_clname, qt_meta_stringdata_octave__SliderControl.stringdata0))
         return static_cast<void*>(this);
     return BaseControl::qt_metacast(_clname);
 }
 
-int QtHandles::SliderControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+int octave::SliderControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = BaseControl::qt_metacall(_c, _id, _a);
     if (_id < 0)
