@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2011-2023 The Octave Project Developers
+// Copyright (C) 2011-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -36,11 +36,11 @@ class TextEdit : public QTextEdit
 
 public:
   TextEdit (QWidget *xparent) : QTextEdit (xparent) { }
-  ~TextEdit (void) = default;
+  ~TextEdit () = default;
 
 signals:
-  void editingFinished (void);
-  void returnPressed (void);
+  void editingFinished ();
+  void returnPressed ();
 
 protected:
   void focusOutEvent (QFocusEvent *event);
