@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_QTerminal_t {
-    QByteArrayData data[27];
-    char stringdata0[482];
+    QByteArrayData data[30];
+    char stringdata0[523];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -45,22 +45,25 @@ QT_MOC_LITERAL(7, 120, 25), // "request_edit_mfile_signal"
 QT_MOC_LITERAL(8, 146, 24), // "request_open_file_signal"
 QT_MOC_LITERAL(9, 171, 22), // "set_screen_size_signal"
 QT_MOC_LITERAL(10, 194, 28), // "clear_command_window_request"
-QT_MOC_LITERAL(11, 223, 13), // "copyClipboard"
-QT_MOC_LITERAL(12, 237, 14), // "pasteClipboard"
-QT_MOC_LITERAL(13, 252, 9), // "selectAll"
-QT_MOC_LITERAL(14, 262, 32), // "handleCustomContextMenuRequested"
-QT_MOC_LITERAL(15, 295, 2), // "at"
-QT_MOC_LITERAL(16, 298, 15), // "notice_settings"
-QT_MOC_LITERAL(17, 314, 19), // "const gui_settings*"
-QT_MOC_LITERAL(18, 334, 8), // "settings"
-QT_MOC_LITERAL(19, 343, 18), // "init_terminal_size"
-QT_MOC_LITERAL(20, 362, 18), // "terminal_interrupt"
-QT_MOC_LITERAL(21, 381, 13), // "run_selection"
-QT_MOC_LITERAL(22, 395, 9), // "edit_file"
-QT_MOC_LITERAL(23, 405, 13), // "edit_selected"
-QT_MOC_LITERAL(24, 419, 18), // "help_on_expression"
-QT_MOC_LITERAL(25, 438, 17), // "doc_on_expression"
-QT_MOC_LITERAL(26, 456, 25) // "handle_visibility_changed"
+QT_MOC_LITERAL(11, 223, 17), // "interpreter_event"
+QT_MOC_LITERAL(12, 241, 20), // "octave::fcn_callback"
+QT_MOC_LITERAL(13, 262, 3), // "fcn"
+QT_MOC_LITERAL(14, 266, 21), // "octave::meth_callback"
+QT_MOC_LITERAL(15, 288, 4), // "meth"
+QT_MOC_LITERAL(16, 293, 13), // "copyClipboard"
+QT_MOC_LITERAL(17, 307, 14), // "pasteClipboard"
+QT_MOC_LITERAL(18, 322, 9), // "selectAll"
+QT_MOC_LITERAL(19, 332, 32), // "handleCustomContextMenuRequested"
+QT_MOC_LITERAL(20, 365, 2), // "at"
+QT_MOC_LITERAL(21, 368, 15), // "notice_settings"
+QT_MOC_LITERAL(22, 384, 18), // "init_terminal_size"
+QT_MOC_LITERAL(23, 403, 18), // "terminal_interrupt"
+QT_MOC_LITERAL(24, 422, 13), // "run_selection"
+QT_MOC_LITERAL(25, 436, 9), // "edit_file"
+QT_MOC_LITERAL(26, 446, 13), // "edit_selected"
+QT_MOC_LITERAL(27, 460, 18), // "help_on_expression"
+QT_MOC_LITERAL(28, 479, 17), // "doc_on_expression"
+QT_MOC_LITERAL(29, 497, 25) // "handle_visibility_changed"
 
     },
     "QTerminal\0report_status_message\0\0"
@@ -69,11 +72,12 @@ QT_MOC_LITERAL(26, 456, 25) // "handle_visibility_changed"
     "request_edit_mfile_signal\0"
     "request_open_file_signal\0"
     "set_screen_size_signal\0"
-    "clear_command_window_request\0copyClipboard\0"
-    "pasteClipboard\0selectAll\0"
+    "clear_command_window_request\0"
+    "interpreter_event\0octave::fcn_callback\0"
+    "fcn\0octave::meth_callback\0meth\0"
+    "copyClipboard\0pasteClipboard\0selectAll\0"
     "handleCustomContextMenuRequested\0at\0"
-    "notice_settings\0const gui_settings*\0"
-    "settings\0init_terminal_size\0"
+    "notice_settings\0init_terminal_size\0"
     "terminal_interrupt\0run_selection\0"
     "edit_file\0edit_selected\0help_on_expression\0"
     "doc_on_expression\0handle_visibility_changed"
@@ -86,38 +90,40 @@ static const uint qt_meta_data_QTerminal[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      22,   14, // methods
+      24,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       9,       // signalCount
+      11,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  124,    2, 0x06 /* Public */,
-       3,    0,  127,    2, 0x06 /* Public */,
-       4,    2,  128,    2, 0x06 /* Public */,
-       5,    1,  133,    2, 0x06 /* Public */,
-       6,    1,  136,    2, 0x06 /* Public */,
-       7,    2,  139,    2, 0x06 /* Public */,
-       8,    3,  144,    2, 0x06 /* Public */,
-       9,    2,  151,    2, 0x06 /* Public */,
-      10,    0,  156,    2, 0x06 /* Public */,
+       1,    1,  134,    2, 0x06 /* Public */,
+       3,    0,  137,    2, 0x06 /* Public */,
+       4,    2,  138,    2, 0x06 /* Public */,
+       5,    1,  143,    2, 0x06 /* Public */,
+       6,    1,  146,    2, 0x06 /* Public */,
+       7,    2,  149,    2, 0x06 /* Public */,
+       8,    3,  154,    2, 0x06 /* Public */,
+       9,    2,  161,    2, 0x06 /* Public */,
+      10,    0,  166,    2, 0x06 /* Public */,
+      11,    1,  167,    2, 0x06 /* Public */,
+      11,    1,  170,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      11,    0,  157,    2, 0x0a /* Public */,
-      12,    0,  158,    2, 0x0a /* Public */,
-      13,    0,  159,    2, 0x0a /* Public */,
-      14,    1,  160,    2, 0x0a /* Public */,
-      16,    1,  163,    2, 0x0a /* Public */,
-      19,    0,  166,    2, 0x0a /* Public */,
-      20,    0,  167,    2, 0x0a /* Public */,
-      21,    0,  168,    2, 0x0a /* Public */,
-      22,    0,  169,    2, 0x0a /* Public */,
-      23,    0,  170,    2, 0x0a /* Public */,
-      24,    0,  171,    2, 0x0a /* Public */,
-      25,    0,  172,    2, 0x0a /* Public */,
-      26,    1,  173,    2, 0x0a /* Public */,
+      16,    0,  173,    2, 0x0a /* Public */,
+      17,    0,  174,    2, 0x0a /* Public */,
+      18,    0,  175,    2, 0x0a /* Public */,
+      19,    1,  176,    2, 0x0a /* Public */,
+      21,    0,  179,    2, 0x0a /* Public */,
+      22,    0,  180,    2, 0x0a /* Public */,
+      23,    0,  181,    2, 0x0a /* Public */,
+      24,    0,  182,    2, 0x0a /* Public */,
+      25,    0,  183,    2, 0x0a /* Public */,
+      26,    0,  184,    2, 0x0a /* Public */,
+      27,    0,  185,    2, 0x0a /* Public */,
+      28,    0,  186,    2, 0x0a /* Public */,
+      29,    1,  187,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    2,
@@ -129,13 +135,15 @@ static const uint qt_meta_data_QTerminal[] = {
     QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int,    2,    2,    2,
     QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
     QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 12,   13,
+    QMetaType::Void, 0x80000000 | 14,   15,
 
  // slots: parameters
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QPoint,   15,
-    QMetaType::Void, 0x80000000 | 17,   18,
+    QMetaType::Void, QMetaType::QPoint,   20,
+    QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -163,19 +171,21 @@ void QTerminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
         case 6: _t->request_open_file_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
         case 7: _t->set_screen_size_signal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
         case 8: _t->clear_command_window_request(); break;
-        case 9: _t->copyClipboard(); break;
-        case 10: _t->pasteClipboard(); break;
-        case 11: _t->selectAll(); break;
-        case 12: _t->handleCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 13: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
-        case 14: _t->init_terminal_size(); break;
-        case 15: _t->terminal_interrupt(); break;
-        case 16: _t->run_selection(); break;
-        case 17: _t->edit_file(); break;
-        case 18: _t->edit_selected(); break;
-        case 19: _t->help_on_expression(); break;
-        case 20: _t->doc_on_expression(); break;
-        case 21: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 9: _t->interpreter_event((*reinterpret_cast< const octave::fcn_callback(*)>(_a[1]))); break;
+        case 10: _t->interpreter_event((*reinterpret_cast< const octave::meth_callback(*)>(_a[1]))); break;
+        case 11: _t->copyClipboard(); break;
+        case 12: _t->pasteClipboard(); break;
+        case 13: _t->selectAll(); break;
+        case 14: _t->handleCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 15: _t->notice_settings(); break;
+        case 16: _t->init_terminal_size(); break;
+        case 17: _t->terminal_interrupt(); break;
+        case 18: _t->run_selection(); break;
+        case 19: _t->edit_file(); break;
+        case 20: _t->edit_selected(); break;
+        case 21: _t->help_on_expression(); break;
+        case 22: _t->doc_on_expression(); break;
+        case 23: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -243,6 +253,20 @@ void QTerminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
                 return;
             }
         }
+        {
+            typedef void (QTerminal::*_t)(const octave::fcn_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::interpreter_event)) {
+                *result = 9;
+                return;
+            }
+        }
+        {
+            typedef void (QTerminal::*_t)(const octave::meth_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::interpreter_event)) {
+                *result = 10;
+                return;
+            }
+        }
     }
 }
 
@@ -271,13 +295,13 @@ int QTerminal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 22)
+        if (_id < 24)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 22;
+        _id -= 24;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 22)
+        if (_id < 24)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 22;
+        _id -= 24;
     }
     return _id;
 }
@@ -342,5 +366,19 @@ void QTerminal::clear_command_window_request()
 {
     QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
 }
+
+// SIGNAL 9
+void QTerminal::interpreter_event(const octave::fcn_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 9, _a);
+}
+
+// SIGNAL 10
+void QTerminal::interpreter_event(const octave::meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 10, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
