@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'ScreenWindow.h'
+** Meta object code from reading C++ file 'moc-ScreenWindow.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/qterminal/libqterminal/unix/ScreenWindow.h"
+#include "libgui/qterminal/libqterminal/unix/moc-ScreenWindow.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'ScreenWindow.h' doesn't include <QObject>."
+#error "The header file 'moc-ScreenWindow.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
