@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__file_editor_tab_t {
-    QByteArrayData data[174];
-    char stringdata0[2822];
+    QByteArrayData data[167];
+    char stringdata0[2661];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -113,101 +113,94 @@ QT_MOC_LITERAL(75, 1200, 6), // "margin"
 QT_MOC_LITERAL(76, 1207, 21), // "Qt::KeyboardModifiers"
 QT_MOC_LITERAL(77, 1229, 5), // "state"
 QT_MOC_LITERAL(78, 1235, 15), // "notice_settings"
-QT_MOC_LITERAL(79, 1251, 19), // "const gui_settings*"
-QT_MOC_LITERAL(80, 1271, 8), // "settings"
-QT_MOC_LITERAL(81, 1280, 4), // "init"
-QT_MOC_LITERAL(82, 1285, 19), // "change_editor_state"
-QT_MOC_LITERAL(83, 1305, 14), // "const QWidget*"
-QT_MOC_LITERAL(84, 1320, 2), // "ID"
-QT_MOC_LITERAL(85, 1323, 9), // "set_focus"
-QT_MOC_LITERAL(86, 1333, 21), // "set_current_directory"
-QT_MOC_LITERAL(87, 1355, 3), // "dir"
-QT_MOC_LITERAL(88, 1359, 12), // "context_help"
-QT_MOC_LITERAL(89, 1372, 12), // "context_edit"
-QT_MOC_LITERAL(90, 1385, 9), // "save_file"
-QT_MOC_LITERAL(91, 1395, 12), // "save_file_as"
-QT_MOC_LITERAL(92, 1408, 10), // "print_file"
-QT_MOC_LITERAL(93, 1419, 8), // "run_file"
-QT_MOC_LITERAL(94, 1428, 9), // "step_into"
-QT_MOC_LITERAL(95, 1438, 11), // "context_run"
-QT_MOC_LITERAL(96, 1450, 15), // "toggle_bookmark"
-QT_MOC_LITERAL(97, 1466, 13), // "next_bookmark"
-QT_MOC_LITERAL(98, 1480, 17), // "previous_bookmark"
-QT_MOC_LITERAL(99, 1498, 15), // "remove_bookmark"
-QT_MOC_LITERAL(100, 1514, 17), // "toggle_breakpoint"
-QT_MOC_LITERAL(101, 1532, 15), // "next_breakpoint"
-QT_MOC_LITERAL(102, 1548, 19), // "previous_breakpoint"
-QT_MOC_LITERAL(103, 1568, 22), // "remove_all_breakpoints"
-QT_MOC_LITERAL(104, 1591, 17), // "scintilla_command"
-QT_MOC_LITERAL(105, 1609, 21), // "comment_selected_text"
-QT_MOC_LITERAL(106, 1631, 9), // "input_str"
-QT_MOC_LITERAL(107, 1641, 23), // "uncomment_selected_text"
-QT_MOC_LITERAL(108, 1665, 20), // "indent_selected_text"
-QT_MOC_LITERAL(109, 1686, 22), // "unindent_selected_text"
-QT_MOC_LITERAL(110, 1709, 34), // "smart_indent_line_or_selected..."
-QT_MOC_LITERAL(111, 1744, 11), // "convert_eol"
-QT_MOC_LITERAL(112, 1756, 22), // "QsciScintilla::EolMode"
-QT_MOC_LITERAL(113, 1779, 7), // "zoom_in"
-QT_MOC_LITERAL(114, 1787, 8), // "zoom_out"
-QT_MOC_LITERAL(115, 1796, 11), // "zoom_normal"
-QT_MOC_LITERAL(116, 1808, 9), // "goto_line"
-QT_MOC_LITERAL(117, 1818, 16), // "move_match_brace"
-QT_MOC_LITERAL(118, 1835, 6), // "select"
-QT_MOC_LITERAL(119, 1842, 20), // "show_auto_completion"
-QT_MOC_LITERAL(120, 1863, 23), // "insert_debugger_pointer"
-QT_MOC_LITERAL(121, 1887, 23), // "delete_debugger_pointer"
-QT_MOC_LITERAL(122, 1911, 20), // "do_breakpoint_marker"
-QT_MOC_LITERAL(123, 1932, 6), // "insert"
-QT_MOC_LITERAL(124, 1939, 17), // "recover_from_exit"
-QT_MOC_LITERAL(125, 1957, 12), // "set_modified"
-QT_MOC_LITERAL(126, 1970, 12), // "set_encoding"
-QT_MOC_LITERAL(127, 1983, 12), // "new_encoding"
-QT_MOC_LITERAL(128, 1996, 9), // "load_file"
-QT_MOC_LITERAL(129, 2006, 8), // "new_file"
-QT_MOC_LITERAL(130, 2015, 8), // "commands"
-QT_MOC_LITERAL(131, 2024, 16), // "file_has_changed"
-QT_MOC_LITERAL(132, 2041, 4), // "path"
-QT_MOC_LITERAL(133, 2046, 8), // "do_close"
-QT_MOC_LITERAL(134, 2055, 24), // "handle_context_menu_edit"
-QT_MOC_LITERAL(135, 2080, 35), // "handle_context_menu_break_con..."
-QT_MOC_LITERAL(136, 2116, 29), // "handle_request_add_breakpoint"
-QT_MOC_LITERAL(137, 2146, 32), // "handle_request_remove_breakpoint"
-QT_MOC_LITERAL(138, 2179, 26), // "update_breakpoints_handler"
-QT_MOC_LITERAL(139, 2206, 6), // "argout"
-QT_MOC_LITERAL(140, 2213, 23), // "update_rowcol_indicator"
-QT_MOC_LITERAL(141, 2237, 3), // "col"
-QT_MOC_LITERAL(142, 2241, 21), // "update_lexer_settings"
-QT_MOC_LITERAL(143, 2263, 16), // "update_apis_only"
-QT_MOC_LITERAL(144, 2280, 28), // "handle_decode_warning_answer"
-QT_MOC_LITERAL(145, 2309, 16), // "QAbstractButton*"
-QT_MOC_LITERAL(146, 2326, 3), // "btn"
-QT_MOC_LITERAL(147, 2330, 25), // "handle_file_reload_answer"
-QT_MOC_LITERAL(148, 2356, 8), // "decision"
-QT_MOC_LITERAL(149, 2365, 25), // "handle_file_resave_answer"
-QT_MOC_LITERAL(150, 2391, 26), // "handle_save_file_as_answer"
-QT_MOC_LITERAL(151, 2418, 32), // "handle_save_file_as_answer_close"
-QT_MOC_LITERAL(152, 2451, 33), // "handle_save_file_as_answer_ca..."
-QT_MOC_LITERAL(153, 2485, 30), // "handle_save_as_filter_selected"
-QT_MOC_LITERAL(154, 2516, 6), // "filter"
-QT_MOC_LITERAL(155, 2523, 26), // "handle_current_enc_changed"
-QT_MOC_LITERAL(156, 2550, 3), // "enc"
-QT_MOC_LITERAL(157, 2554, 14), // "save_apis_info"
-QT_MOC_LITERAL(158, 2569, 17), // "auto_margin_width"
-QT_MOC_LITERAL(159, 2587, 19), // "handle_cursor_moved"
-QT_MOC_LITERAL(160, 2607, 17), // "handle_char_added"
-QT_MOC_LITERAL(161, 2625, 9), // "character"
-QT_MOC_LITERAL(162, 2635, 19), // "handle_double_click"
-QT_MOC_LITERAL(163, 2655, 1), // "p"
-QT_MOC_LITERAL(164, 2657, 1), // "l"
-QT_MOC_LITERAL(165, 2659, 8), // "modifier"
-QT_MOC_LITERAL(166, 2668, 20), // "handle_lines_changed"
-QT_MOC_LITERAL(167, 2689, 18), // "handle_remove_next"
-QT_MOC_LITERAL(168, 2708, 16), // "handle_dbstop_if"
-QT_MOC_LITERAL(169, 2725, 22), // "handle_add_octave_apis"
-QT_MOC_LITERAL(170, 2748, 11), // "api_entries"
-QT_MOC_LITERAL(171, 2760, 24), // "handle_api_entries_added"
-QT_MOC_LITERAL(172, 2785, 12), // "do_save_file"
-QT_MOC_LITERAL(173, 2798, 23) // "confirm_dbquit_and_save"
+QT_MOC_LITERAL(79, 1251, 4), // "init"
+QT_MOC_LITERAL(80, 1256, 19), // "change_editor_state"
+QT_MOC_LITERAL(81, 1276, 14), // "const QWidget*"
+QT_MOC_LITERAL(82, 1291, 2), // "ID"
+QT_MOC_LITERAL(83, 1294, 9), // "set_focus"
+QT_MOC_LITERAL(84, 1304, 21), // "set_current_directory"
+QT_MOC_LITERAL(85, 1326, 3), // "dir"
+QT_MOC_LITERAL(86, 1330, 12), // "context_help"
+QT_MOC_LITERAL(87, 1343, 12), // "context_edit"
+QT_MOC_LITERAL(88, 1356, 9), // "save_file"
+QT_MOC_LITERAL(89, 1366, 12), // "save_file_as"
+QT_MOC_LITERAL(90, 1379, 10), // "print_file"
+QT_MOC_LITERAL(91, 1390, 8), // "run_file"
+QT_MOC_LITERAL(92, 1399, 9), // "step_into"
+QT_MOC_LITERAL(93, 1409, 11), // "context_run"
+QT_MOC_LITERAL(94, 1421, 15), // "toggle_bookmark"
+QT_MOC_LITERAL(95, 1437, 13), // "next_bookmark"
+QT_MOC_LITERAL(96, 1451, 17), // "previous_bookmark"
+QT_MOC_LITERAL(97, 1469, 15), // "remove_bookmark"
+QT_MOC_LITERAL(98, 1485, 17), // "toggle_breakpoint"
+QT_MOC_LITERAL(99, 1503, 15), // "next_breakpoint"
+QT_MOC_LITERAL(100, 1519, 19), // "previous_breakpoint"
+QT_MOC_LITERAL(101, 1539, 22), // "remove_all_breakpoints"
+QT_MOC_LITERAL(102, 1562, 17), // "scintilla_command"
+QT_MOC_LITERAL(103, 1580, 21), // "comment_selected_text"
+QT_MOC_LITERAL(104, 1602, 9), // "input_str"
+QT_MOC_LITERAL(105, 1612, 23), // "uncomment_selected_text"
+QT_MOC_LITERAL(106, 1636, 20), // "indent_selected_text"
+QT_MOC_LITERAL(107, 1657, 22), // "unindent_selected_text"
+QT_MOC_LITERAL(108, 1680, 34), // "smart_indent_line_or_selected..."
+QT_MOC_LITERAL(109, 1715, 11), // "convert_eol"
+QT_MOC_LITERAL(110, 1727, 22), // "QsciScintilla::EolMode"
+QT_MOC_LITERAL(111, 1750, 7), // "zoom_in"
+QT_MOC_LITERAL(112, 1758, 8), // "zoom_out"
+QT_MOC_LITERAL(113, 1767, 11), // "zoom_normal"
+QT_MOC_LITERAL(114, 1779, 9), // "goto_line"
+QT_MOC_LITERAL(115, 1789, 16), // "move_match_brace"
+QT_MOC_LITERAL(116, 1806, 6), // "select"
+QT_MOC_LITERAL(117, 1813, 20), // "show_auto_completion"
+QT_MOC_LITERAL(118, 1834, 23), // "insert_debugger_pointer"
+QT_MOC_LITERAL(119, 1858, 23), // "delete_debugger_pointer"
+QT_MOC_LITERAL(120, 1882, 20), // "do_breakpoint_marker"
+QT_MOC_LITERAL(121, 1903, 6), // "insert"
+QT_MOC_LITERAL(122, 1910, 17), // "recover_from_exit"
+QT_MOC_LITERAL(123, 1928, 12), // "set_modified"
+QT_MOC_LITERAL(124, 1941, 12), // "set_encoding"
+QT_MOC_LITERAL(125, 1954, 12), // "new_encoding"
+QT_MOC_LITERAL(126, 1967, 9), // "load_file"
+QT_MOC_LITERAL(127, 1977, 8), // "new_file"
+QT_MOC_LITERAL(128, 1986, 8), // "commands"
+QT_MOC_LITERAL(129, 1995, 16), // "file_has_changed"
+QT_MOC_LITERAL(130, 2012, 4), // "path"
+QT_MOC_LITERAL(131, 2017, 8), // "do_close"
+QT_MOC_LITERAL(132, 2026, 24), // "handle_context_menu_edit"
+QT_MOC_LITERAL(133, 2051, 35), // "handle_context_menu_break_con..."
+QT_MOC_LITERAL(134, 2087, 29), // "handle_request_add_breakpoint"
+QT_MOC_LITERAL(135, 2117, 32), // "handle_request_remove_breakpoint"
+QT_MOC_LITERAL(136, 2150, 26), // "update_breakpoints_handler"
+QT_MOC_LITERAL(137, 2177, 6), // "argout"
+QT_MOC_LITERAL(138, 2184, 23), // "update_rowcol_indicator"
+QT_MOC_LITERAL(139, 2208, 3), // "col"
+QT_MOC_LITERAL(140, 2212, 21), // "update_lexer_settings"
+QT_MOC_LITERAL(141, 2234, 16), // "update_apis_only"
+QT_MOC_LITERAL(142, 2251, 28), // "handle_decode_warning_answer"
+QT_MOC_LITERAL(143, 2280, 16), // "QAbstractButton*"
+QT_MOC_LITERAL(144, 2297, 3), // "btn"
+QT_MOC_LITERAL(145, 2301, 25), // "handle_file_reload_answer"
+QT_MOC_LITERAL(146, 2327, 8), // "decision"
+QT_MOC_LITERAL(147, 2336, 25), // "handle_file_resave_answer"
+QT_MOC_LITERAL(148, 2362, 26), // "handle_current_enc_changed"
+QT_MOC_LITERAL(149, 2389, 3), // "enc"
+QT_MOC_LITERAL(150, 2393, 14), // "save_apis_info"
+QT_MOC_LITERAL(151, 2408, 17), // "auto_margin_width"
+QT_MOC_LITERAL(152, 2426, 19), // "handle_cursor_moved"
+QT_MOC_LITERAL(153, 2446, 17), // "handle_char_added"
+QT_MOC_LITERAL(154, 2464, 9), // "character"
+QT_MOC_LITERAL(155, 2474, 19), // "handle_double_click"
+QT_MOC_LITERAL(156, 2494, 1), // "p"
+QT_MOC_LITERAL(157, 2496, 1), // "l"
+QT_MOC_LITERAL(158, 2498, 8), // "modifier"
+QT_MOC_LITERAL(159, 2507, 20), // "handle_lines_changed"
+QT_MOC_LITERAL(160, 2528, 18), // "handle_remove_next"
+QT_MOC_LITERAL(161, 2547, 16), // "handle_dbstop_if"
+QT_MOC_LITERAL(162, 2564, 22), // "handle_add_octave_apis"
+QT_MOC_LITERAL(163, 2587, 11), // "api_entries"
+QT_MOC_LITERAL(164, 2599, 24), // "handle_api_entries_added"
+QT_MOC_LITERAL(165, 2624, 12), // "do_save_file"
+QT_MOC_LITERAL(166, 2637, 23) // "confirm_dbquit_and_save"
 
     },
     "octave::file_editor_tab\0tab_ready_to_close\0"
@@ -245,8 +238,7 @@ QT_MOC_LITERAL(173, 2798, 23) // "confirm_dbquit_and_save"
     "handle_copy_available\0enableCopy\0"
     "handle_margin_clicked\0margin\0"
     "Qt::KeyboardModifiers\0state\0notice_settings\0"
-    "const gui_settings*\0settings\0init\0"
-    "change_editor_state\0const QWidget*\0"
+    "init\0change_editor_state\0const QWidget*\0"
     "ID\0set_focus\0set_current_directory\0"
     "dir\0context_help\0context_edit\0save_file\0"
     "save_file_as\0print_file\0run_file\0"
@@ -277,10 +269,6 @@ QT_MOC_LITERAL(173, 2798, 23) // "confirm_dbquit_and_save"
     "handle_decode_warning_answer\0"
     "QAbstractButton*\0btn\0handle_file_reload_answer\0"
     "decision\0handle_file_resave_answer\0"
-    "handle_save_file_as_answer\0"
-    "handle_save_file_as_answer_close\0"
-    "handle_save_file_as_answer_cancel\0"
-    "handle_save_as_filter_selected\0filter\0"
     "handle_current_enc_changed\0enc\0"
     "save_apis_info\0auto_margin_width\0"
     "handle_cursor_moved\0handle_char_added\0"
@@ -299,7 +287,7 @@ static const uint qt_meta_data_octave__file_editor_tab[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-     115,   14, // methods
+     111,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -307,123 +295,119 @@ static const uint qt_meta_data_octave__file_editor_tab[] = {
       32,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    0,  589,    2, 0x06 /* Public */,
-       3,    3,  590,    2, 0x06 /* Public */,
-       7,    3,  597,    2, 0x06 /* Public */,
-      11,    1,  604,    2, 0x06 /* Public */,
-      13,    1,  607,    2, 0x06 /* Public */,
-      16,    0,  610,    2, 0x06 /* Public */,
-      17,    2,  611,    2, 0x06 /* Public */,
-      20,    2,  616,    2, 0x06 /* Public */,
-      23,    1,  621,    2, 0x06 /* Public */,
-      26,    2,  624,    2, 0x06 /* Public */,
-      26,    1,  629,    2, 0x26 /* Public | MethodCloned */,
-      27,    4,  632,    2, 0x06 /* Public */,
-      28,    0,  641,    2, 0x06 /* Public */,
-      29,    1,  642,    2, 0x06 /* Public */,
-      32,    1,  645,    2, 0x06 /* Public */,
-      34,    1,  648,    2, 0x06 /* Public */,
-      36,    0,  651,    2, 0x06 /* Public */,
-      37,    3,  652,    2, 0x06 /* Public */,
-      42,    3,  659,    2, 0x06 /* Public */,
-      44,    2,  666,    2, 0x06 /* Public */,
-      49,    1,  671,    2, 0x06 /* Public */,
-      50,    0,  674,    2, 0x06 /* Public */,
-      51,    0,  675,    2, 0x06 /* Public */,
-      52,    1,  676,    2, 0x06 /* Public */,
-      52,    1,  679,    2, 0x06 /* Public */,
-      57,    1,  682,    2, 0x06 /* Public */,
-      59,    3,  685,    2, 0x06 /* Public */,
-      63,    2,  692,    2, 0x06 /* Public */,
-      64,    1,  697,    2, 0x06 /* Public */,
-      65,    0,  700,    2, 0x06 /* Public */,
-      66,    3,  701,    2, 0x06 /* Public */,
-      69,    4,  708,    2, 0x06 /* Public */,
+       1,    0,  569,    2, 0x06 /* Public */,
+       3,    3,  570,    2, 0x06 /* Public */,
+       7,    3,  577,    2, 0x06 /* Public */,
+      11,    1,  584,    2, 0x06 /* Public */,
+      13,    1,  587,    2, 0x06 /* Public */,
+      16,    0,  590,    2, 0x06 /* Public */,
+      17,    2,  591,    2, 0x06 /* Public */,
+      20,    2,  596,    2, 0x06 /* Public */,
+      23,    1,  601,    2, 0x06 /* Public */,
+      26,    2,  604,    2, 0x06 /* Public */,
+      26,    1,  609,    2, 0x26 /* Public | MethodCloned */,
+      27,    4,  612,    2, 0x06 /* Public */,
+      28,    0,  621,    2, 0x06 /* Public */,
+      29,    1,  622,    2, 0x06 /* Public */,
+      32,    1,  625,    2, 0x06 /* Public */,
+      34,    1,  628,    2, 0x06 /* Public */,
+      36,    0,  631,    2, 0x06 /* Public */,
+      37,    3,  632,    2, 0x06 /* Public */,
+      42,    3,  639,    2, 0x06 /* Public */,
+      44,    2,  646,    2, 0x06 /* Public */,
+      49,    1,  651,    2, 0x06 /* Public */,
+      50,    0,  654,    2, 0x06 /* Public */,
+      51,    0,  655,    2, 0x06 /* Public */,
+      52,    1,  656,    2, 0x06 /* Public */,
+      52,    1,  659,    2, 0x06 /* Public */,
+      57,    1,  662,    2, 0x06 /* Public */,
+      59,    3,  665,    2, 0x06 /* Public */,
+      63,    2,  672,    2, 0x06 /* Public */,
+      64,    1,  677,    2, 0x06 /* Public */,
+      65,    0,  680,    2, 0x06 /* Public */,
+      66,    3,  681,    2, 0x06 /* Public */,
+      69,    4,  688,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      71,    1,  717,    2, 0x0a /* Public */,
-      72,    1,  720,    2, 0x0a /* Public */,
-      74,    3,  723,    2, 0x0a /* Public */,
-      78,    2,  730,    2, 0x0a /* Public */,
-      78,    1,  735,    2, 0x2a /* Public | MethodCloned */,
-      82,    1,  738,    2, 0x0a /* Public */,
-      85,    1,  741,    2, 0x0a /* Public */,
-      86,    1,  744,    2, 0x0a /* Public */,
-      88,    2,  747,    2, 0x0a /* Public */,
-      89,    1,  752,    2, 0x0a /* Public */,
-      90,    1,  755,    2, 0x0a /* Public */,
-      90,    3,  758,    2, 0x0a /* Public */,
-      91,    1,  765,    2, 0x0a /* Public */,
-      92,    1,  768,    2, 0x0a /* Public */,
-      93,    2,  771,    2, 0x0a /* Public */,
-      93,    1,  776,    2, 0x2a /* Public | MethodCloned */,
-      95,    1,  779,    2, 0x0a /* Public */,
-      96,    1,  782,    2, 0x0a /* Public */,
-      97,    1,  785,    2, 0x0a /* Public */,
-      98,    1,  788,    2, 0x0a /* Public */,
-      99,    1,  791,    2, 0x0a /* Public */,
-     100,    1,  794,    2, 0x0a /* Public */,
-     101,    1,  797,    2, 0x0a /* Public */,
-     102,    1,  800,    2, 0x0a /* Public */,
-     103,    1,  803,    2, 0x0a /* Public */,
-     104,    2,  806,    2, 0x0a /* Public */,
-     105,    2,  811,    2, 0x0a /* Public */,
-     107,    1,  816,    2, 0x0a /* Public */,
-     108,    1,  819,    2, 0x0a /* Public */,
-     109,    1,  822,    2, 0x0a /* Public */,
-     110,    1,  825,    2, 0x0a /* Public */,
-     111,    2,  828,    2, 0x0a /* Public */,
-     113,    1,  833,    2, 0x0a /* Public */,
-     114,    1,  836,    2, 0x0a /* Public */,
-     115,    1,  839,    2, 0x0a /* Public */,
-     116,    2,  842,    2, 0x0a /* Public */,
-     116,    1,  847,    2, 0x2a /* Public | MethodCloned */,
-     117,    2,  850,    2, 0x0a /* Public */,
-     119,    1,  855,    2, 0x0a /* Public */,
-     120,    2,  858,    2, 0x0a /* Public */,
-     120,    1,  863,    2, 0x2a /* Public | MethodCloned */,
-     121,    2,  866,    2, 0x0a /* Public */,
-     121,    1,  871,    2, 0x2a /* Public | MethodCloned */,
-     122,    4,  874,    2, 0x0a /* Public */,
-     122,    3,  883,    2, 0x2a /* Public | MethodCloned */,
-     122,    2,  890,    2, 0x2a /* Public | MethodCloned */,
-     124,    0,  895,    2, 0x0a /* Public */,
-     125,    1,  896,    2, 0x0a /* Public */,
-     125,    0,  899,    2, 0x2a /* Public | MethodCloned */,
-     126,    1,  900,    2, 0x0a /* Public */,
-     128,    1,  903,    2, 0x0a /* Public */,
-     129,    1,  906,    2, 0x0a /* Public */,
-     129,    0,  909,    2, 0x2a /* Public | MethodCloned */,
-     131,    2,  910,    2, 0x0a /* Public */,
-     131,    1,  915,    2, 0x2a /* Public | MethodCloned */,
-     134,    1,  918,    2, 0x0a /* Public */,
-     135,    1,  921,    2, 0x0a /* Public */,
-     136,    2,  924,    2, 0x0a /* Public */,
-     137,    1,  929,    2, 0x0a /* Public */,
-     138,    1,  932,    2, 0x0a /* Public */,
-     140,    2,  935,    2, 0x0a /* Public */,
-     142,    1,  940,    2, 0x0a /* Public */,
-     142,    0,  943,    2, 0x2a /* Public | MethodCloned */,
-     144,    1,  944,    2, 0x08 /* Private */,
-     147,    1,  947,    2, 0x08 /* Private */,
-     149,    1,  950,    2, 0x08 /* Private */,
-     150,    1,  953,    2, 0x08 /* Private */,
-     151,    1,  956,    2, 0x08 /* Private */,
-     152,    0,  959,    2, 0x08 /* Private */,
-     153,    1,  960,    2, 0x08 /* Private */,
-     155,    1,  963,    2, 0x08 /* Private */,
-     157,    0,  966,    2, 0x08 /* Private */,
-     158,    0,  967,    2, 0x08 /* Private */,
-     159,    2,  968,    2, 0x08 /* Private */,
-     160,    1,  973,    2, 0x08 /* Private */,
-     162,    3,  976,    2, 0x08 /* Private */,
-     166,    0,  983,    2, 0x08 /* Private */,
-     167,    1,  984,    2, 0x08 /* Private */,
-     168,    3,  987,    2, 0x08 /* Private */,
-     169,    1,  994,    2, 0x08 /* Private */,
-     171,    0,  997,    2, 0x08 /* Private */,
-     172,    3,  998,    2, 0x08 /* Private */,
-     173,    4, 1005,    2, 0x08 /* Private */,
+      71,    1,  697,    2, 0x0a /* Public */,
+      72,    1,  700,    2, 0x0a /* Public */,
+      74,    3,  703,    2, 0x0a /* Public */,
+      78,    1,  710,    2, 0x0a /* Public */,
+      78,    0,  713,    2, 0x2a /* Public | MethodCloned */,
+      80,    1,  714,    2, 0x0a /* Public */,
+      83,    1,  717,    2, 0x0a /* Public */,
+      84,    1,  720,    2, 0x0a /* Public */,
+      86,    2,  723,    2, 0x0a /* Public */,
+      87,    1,  728,    2, 0x0a /* Public */,
+      88,    1,  731,    2, 0x0a /* Public */,
+      88,    3,  734,    2, 0x0a /* Public */,
+      89,    1,  741,    2, 0x0a /* Public */,
+      90,    1,  744,    2, 0x0a /* Public */,
+      91,    2,  747,    2, 0x0a /* Public */,
+      91,    1,  752,    2, 0x2a /* Public | MethodCloned */,
+      93,    1,  755,    2, 0x0a /* Public */,
+      94,    1,  758,    2, 0x0a /* Public */,
+      95,    1,  761,    2, 0x0a /* Public */,
+      96,    1,  764,    2, 0x0a /* Public */,
+      97,    1,  767,    2, 0x0a /* Public */,
+      98,    1,  770,    2, 0x0a /* Public */,
+      99,    1,  773,    2, 0x0a /* Public */,
+     100,    1,  776,    2, 0x0a /* Public */,
+     101,    1,  779,    2, 0x0a /* Public */,
+     102,    2,  782,    2, 0x0a /* Public */,
+     103,    2,  787,    2, 0x0a /* Public */,
+     105,    1,  792,    2, 0x0a /* Public */,
+     106,    1,  795,    2, 0x0a /* Public */,
+     107,    1,  798,    2, 0x0a /* Public */,
+     108,    1,  801,    2, 0x0a /* Public */,
+     109,    2,  804,    2, 0x0a /* Public */,
+     111,    1,  809,    2, 0x0a /* Public */,
+     112,    1,  812,    2, 0x0a /* Public */,
+     113,    1,  815,    2, 0x0a /* Public */,
+     114,    2,  818,    2, 0x0a /* Public */,
+     114,    1,  823,    2, 0x2a /* Public | MethodCloned */,
+     115,    2,  826,    2, 0x0a /* Public */,
+     117,    1,  831,    2, 0x0a /* Public */,
+     118,    2,  834,    2, 0x0a /* Public */,
+     118,    1,  839,    2, 0x2a /* Public | MethodCloned */,
+     119,    2,  842,    2, 0x0a /* Public */,
+     119,    1,  847,    2, 0x2a /* Public | MethodCloned */,
+     120,    4,  850,    2, 0x0a /* Public */,
+     120,    3,  859,    2, 0x2a /* Public | MethodCloned */,
+     120,    2,  866,    2, 0x2a /* Public | MethodCloned */,
+     122,    0,  871,    2, 0x0a /* Public */,
+     123,    1,  872,    2, 0x0a /* Public */,
+     123,    0,  875,    2, 0x2a /* Public | MethodCloned */,
+     124,    1,  876,    2, 0x0a /* Public */,
+     126,    1,  879,    2, 0x0a /* Public */,
+     127,    1,  882,    2, 0x0a /* Public */,
+     127,    0,  885,    2, 0x2a /* Public | MethodCloned */,
+     129,    2,  886,    2, 0x0a /* Public */,
+     129,    1,  891,    2, 0x2a /* Public | MethodCloned */,
+     132,    1,  894,    2, 0x0a /* Public */,
+     133,    1,  897,    2, 0x0a /* Public */,
+     134,    2,  900,    2, 0x0a /* Public */,
+     135,    1,  905,    2, 0x0a /* Public */,
+     136,    1,  908,    2, 0x0a /* Public */,
+     138,    2,  911,    2, 0x0a /* Public */,
+     140,    1,  916,    2, 0x0a /* Public */,
+     140,    0,  919,    2, 0x2a /* Public | MethodCloned */,
+     142,    1,  920,    2, 0x08 /* Private */,
+     145,    1,  923,    2, 0x08 /* Private */,
+     147,    1,  926,    2, 0x08 /* Private */,
+     148,    1,  929,    2, 0x08 /* Private */,
+     150,    0,  932,    2, 0x08 /* Private */,
+     151,    0,  933,    2, 0x08 /* Private */,
+     152,    2,  934,    2, 0x08 /* Private */,
+     153,    1,  939,    2, 0x08 /* Private */,
+     155,    3,  942,    2, 0x08 /* Private */,
+     159,    0,  949,    2, 0x08 /* Private */,
+     160,    1,  950,    2, 0x08 /* Private */,
+     161,    3,  953,    2, 0x08 /* Private */,
+     162,    1,  960,    2, 0x08 /* Private */,
+     164,    0,  963,    2, 0x08 /* Private */,
+     165,    3,  964,    2, 0x08 /* Private */,
+     166,    4,  971,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void,
@@ -463,83 +447,79 @@ static const uint qt_meta_data_octave__file_editor_tab[] = {
     QMetaType::Void, QMetaType::Bool,    6,
     QMetaType::Void, QMetaType::Bool,   73,
     QMetaType::Void, QMetaType::Int, QMetaType::Int, 0x80000000 | 76,   61,   75,   77,
-    QMetaType::Void, 0x80000000 | 79, QMetaType::Bool,   80,   81,
-    QMetaType::Void, 0x80000000 | 79,   80,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, QMetaType::QString,   87,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Bool,   84,    2,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::QString, QMetaType::Bool,   84,    4,   22,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Bool,   84,   94,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::UInt,    2,    2,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Bool,   84,  106,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, 0x80000000 | 112,   84,    2,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Int,   84,   61,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Bool,   84,  118,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Int,   84,   61,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, 0x80000000 | 83, QMetaType::Int,   84,   61,
-    QMetaType::Void, 0x80000000 | 83,   84,
-    QMetaType::Void, QMetaType::Bool, 0x80000000 | 83, QMetaType::Int, QMetaType::QString,  123,   84,   61,   62,
-    QMetaType::Void, QMetaType::Bool, 0x80000000 | 83, QMetaType::Int,  123,   84,   61,
-    QMetaType::Void, QMetaType::Bool, 0x80000000 | 83,  123,   84,
+    QMetaType::Void, QMetaType::Bool,   79,
+    QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, QMetaType::QString,   85,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Bool,   82,    2,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::QString, QMetaType::Bool,   82,    4,   22,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Bool,   82,   92,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::UInt,    2,    2,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Bool,   82,  104,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, 0x80000000 | 110,   82,    2,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Int,   82,   61,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Bool,   82,  116,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Int,   82,   61,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, 0x80000000 | 81, QMetaType::Int,   82,   61,
+    QMetaType::Void, 0x80000000 | 81,   82,
+    QMetaType::Void, QMetaType::Bool, 0x80000000 | 81, QMetaType::Int, QMetaType::QString,  121,   82,   61,   62,
+    QMetaType::Void, QMetaType::Bool, 0x80000000 | 81, QMetaType::Int,  121,   82,   61,
+    QMetaType::Void, QMetaType::Bool, 0x80000000 | 81,  121,   82,
     QMetaType::Void,
     QMetaType::Void, QMetaType::Bool,    6,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,  127,
+    QMetaType::Void, QMetaType::QString,  125,
     QMetaType::QString, QMetaType::QString,    4,
-    QMetaType::Void, QMetaType::QString,  130,
+    QMetaType::Void, QMetaType::QString,  128,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString, QMetaType::Bool,  132,  133,
-    QMetaType::Void, QMetaType::QString,  132,
+    QMetaType::Void, QMetaType::QString, QMetaType::Bool,  130,  131,
+    QMetaType::Void, QMetaType::QString,  130,
     QMetaType::Void, QMetaType::QString,    2,
     QMetaType::Void, QMetaType::Int,   43,
     QMetaType::Void, QMetaType::Int, QMetaType::QString,   61,   62,
     QMetaType::Void, QMetaType::Int,   61,
-    QMetaType::Void, 0x80000000 | 30,  139,
-    QMetaType::Void, QMetaType::Int, QMetaType::Int,   61,  141,
-    QMetaType::Void, QMetaType::Bool,  143,
+    QMetaType::Void, 0x80000000 | 30,  137,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int,   61,  139,
+    QMetaType::Void, QMetaType::Bool,  141,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 145,  146,
-    QMetaType::Void, QMetaType::Int,  148,
-    QMetaType::Void, QMetaType::Int,  148,
-    QMetaType::Void, QMetaType::QString,    4,
-    QMetaType::Void, QMetaType::QString,    4,
-    QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,  154,
-    QMetaType::Void, QMetaType::QString,  156,
+    QMetaType::Void, 0x80000000 | 143,  144,
+    QMetaType::Void, QMetaType::Int,  146,
+    QMetaType::Void, QMetaType::Int,  146,
+    QMetaType::Void, QMetaType::QString,  149,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Int, QMetaType::Int,   61,  141,
-    QMetaType::Void, QMetaType::Int,  161,
-    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,  163,  164,  165,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int,   61,  139,
+    QMetaType::Void, QMetaType::Int,  154,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,  156,  157,  158,
     QMetaType::Void,
     QMetaType::Void, QMetaType::Int,   58,
     QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,   60,   61,   62,
-    QMetaType::Void, QMetaType::QStringList,  170,
+    QMetaType::Void, QMetaType::QStringList,  163,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   67,   22,   68,
     QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   67,   70,   22,   68,
@@ -588,8 +568,8 @@ void octave::file_editor_tab::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 32: _t->update_window_title((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 33: _t->handle_copy_available((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 34: _t->handle_margin_clicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
-        case 35: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
-        case 36: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 35: _t->notice_settings((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 36: _t->notice_settings(); break;
         case 37: _t->change_editor_state((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
         case 38: _t->set_focus((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
         case 39: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
@@ -652,23 +632,19 @@ void octave::file_editor_tab::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 95: _t->handle_decode_warning_answer((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
         case 96: _t->handle_file_reload_answer((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 97: _t->handle_file_resave_answer((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 98: _t->handle_save_file_as_answer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 99: _t->handle_save_file_as_answer_close((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 100: _t->handle_save_file_as_answer_cancel(); break;
-        case 101: _t->handle_save_as_filter_selected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 102: _t->handle_current_enc_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 103: _t->save_apis_info(); break;
-        case 104: _t->auto_margin_width(); break;
-        case 105: _t->handle_cursor_moved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 106: _t->handle_char_added((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 107: _t->handle_double_click((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
-        case 108: _t->handle_lines_changed(); break;
-        case 109: _t->handle_remove_next((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 110: _t->handle_dbstop_if((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
-        case 111: _t->handle_add_octave_apis((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
-        case 112: _t->handle_api_entries_added(); break;
-        case 113: _t->do_save_file((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
-        case 114: _t->confirm_dbquit_and_save((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
+        case 98: _t->handle_current_enc_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 99: _t->save_apis_info(); break;
+        case 100: _t->auto_margin_width(); break;
+        case 101: _t->handle_cursor_moved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 102: _t->handle_char_added((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 103: _t->handle_double_click((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
+        case 104: _t->handle_lines_changed(); break;
+        case 105: _t->handle_remove_next((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 106: _t->handle_dbstop_if((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
+        case 107: _t->handle_add_octave_apis((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
+        case 108: _t->handle_api_entries_added(); break;
+        case 109: _t->do_save_file((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
+        case 110: _t->confirm_dbquit_and_save((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -918,13 +894,13 @@ int octave::file_editor_tab::qt_metacall(QMetaObject::Call _c, int _id, void **_
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 115)
+        if (_id < 111)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 115;
+        _id -= 111;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 115)
+        if (_id < 111)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 115;
+        _id -= 111;
     }
     return _id;
 }
