@@ -12,6 +12,7 @@
 #include "libgui/src/m-editor/moc-octave-qscintilla.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
+#include <QtCore/QPointer>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-octave-qscintilla.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
@@ -24,8 +25,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__octave_qscintilla_t {
-    QByteArrayData data[35];
-    char stringdata0[678];
+    QByteArrayData data[36];
+    char stringdata0[714];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -46,29 +47,30 @@ QT_MOC_LITERAL(8, 136, 24), // "context_menu_edit_signal"
 QT_MOC_LITERAL(9, 161, 21), // "qsci_has_focus_signal"
 QT_MOC_LITERAL(10, 183, 13), // "status_update"
 QT_MOC_LITERAL(11, 197, 15), // "show_doc_signal"
-QT_MOC_LITERAL(12, 213, 35), // "context_menu_break_condition_..."
-QT_MOC_LITERAL(13, 249, 23), // "context_menu_break_once"
-QT_MOC_LITERAL(14, 273, 28), // "ctx_menu_run_finished_signal"
-QT_MOC_LITERAL(15, 302, 15), // "QTemporaryFile*"
-QT_MOC_LITERAL(16, 318, 34), // "focus_console_after_command_s..."
-QT_MOC_LITERAL(17, 353, 17), // "interpreter_event"
-QT_MOC_LITERAL(18, 371, 12), // "fcn_callback"
-QT_MOC_LITERAL(19, 384, 3), // "fcn"
-QT_MOC_LITERAL(20, 388, 13), // "meth_callback"
-QT_MOC_LITERAL(21, 402, 4), // "meth"
-QT_MOC_LITERAL(22, 407, 23), // "handle_enter_debug_mode"
-QT_MOC_LITERAL(23, 431, 22), // "handle_exit_debug_mode"
-QT_MOC_LITERAL(24, 454, 21), // "ctx_menu_run_finished"
-QT_MOC_LITERAL(25, 476, 16), // "contextmenu_help"
-QT_MOC_LITERAL(26, 493, 15), // "contextmenu_doc"
-QT_MOC_LITERAL(27, 509, 20), // "contextmenu_help_doc"
-QT_MOC_LITERAL(28, 530, 16), // "contextmenu_edit"
-QT_MOC_LITERAL(29, 547, 15), // "contextmenu_run"
-QT_MOC_LITERAL(30, 563, 26), // "contextmenu_run_temp_error"
-QT_MOC_LITERAL(31, 590, 27), // "contextmenu_break_condition"
-QT_MOC_LITERAL(32, 618, 22), // "contextmenu_break_once"
-QT_MOC_LITERAL(33, 641, 12), // "text_changed"
-QT_MOC_LITERAL(34, 654, 23) // "cursor_position_changed"
+QT_MOC_LITERAL(12, 213, 26), // "show_symbol_tooltip_signal"
+QT_MOC_LITERAL(13, 240, 35), // "context_menu_break_condition_..."
+QT_MOC_LITERAL(14, 276, 23), // "context_menu_break_once"
+QT_MOC_LITERAL(15, 300, 28), // "ctx_menu_run_finished_signal"
+QT_MOC_LITERAL(16, 329, 24), // "QPointer<QTemporaryFile>"
+QT_MOC_LITERAL(17, 354, 34), // "focus_console_after_command_s..."
+QT_MOC_LITERAL(18, 389, 17), // "interpreter_event"
+QT_MOC_LITERAL(19, 407, 12), // "fcn_callback"
+QT_MOC_LITERAL(20, 420, 3), // "fcn"
+QT_MOC_LITERAL(21, 424, 13), // "meth_callback"
+QT_MOC_LITERAL(22, 438, 4), // "meth"
+QT_MOC_LITERAL(23, 443, 23), // "handle_enter_debug_mode"
+QT_MOC_LITERAL(24, 467, 22), // "handle_exit_debug_mode"
+QT_MOC_LITERAL(25, 490, 21), // "ctx_menu_run_finished"
+QT_MOC_LITERAL(26, 512, 16), // "contextmenu_help"
+QT_MOC_LITERAL(27, 529, 15), // "contextmenu_doc"
+QT_MOC_LITERAL(28, 545, 20), // "contextmenu_help_doc"
+QT_MOC_LITERAL(29, 566, 16), // "contextmenu_edit"
+QT_MOC_LITERAL(30, 583, 15), // "contextmenu_run"
+QT_MOC_LITERAL(31, 599, 26), // "contextmenu_run_temp_error"
+QT_MOC_LITERAL(32, 626, 27), // "contextmenu_break_condition"
+QT_MOC_LITERAL(33, 654, 22), // "contextmenu_break_once"
+QT_MOC_LITERAL(34, 677, 12), // "text_changed"
+QT_MOC_LITERAL(35, 690, 23) // "cursor_position_changed"
 
     },
     "octave::octave_qscintilla\0"
@@ -77,10 +79,12 @@ QT_MOC_LITERAL(34, 654, 23) // "cursor_position_changed"
     "create_context_menu_signal\0QMenu*\0"
     "context_menu_edit_signal\0qsci_has_focus_signal\0"
     "status_update\0show_doc_signal\0"
+    "show_symbol_tooltip_signal\0"
     "context_menu_break_condition_signal\0"
     "context_menu_break_once\0"
     "ctx_menu_run_finished_signal\0"
-    "QTemporaryFile*\0focus_console_after_command_signal\0"
+    "QPointer<QTemporaryFile>\0"
+    "focus_console_after_command_signal\0"
     "interpreter_event\0fcn_callback\0fcn\0"
     "meth_callback\0meth\0handle_enter_debug_mode\0"
     "handle_exit_debug_mode\0ctx_menu_run_finished\0"
@@ -99,42 +103,43 @@ static const uint qt_meta_data_octave__octave_qscintilla[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      26,   14, // methods
+      27,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-      13,       // signalCount
+      14,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    2,  144,    2, 0x06 /* Public */,
-       5,    1,  149,    2, 0x06 /* Public */,
-       6,    1,  152,    2, 0x06 /* Public */,
-       8,    1,  155,    2, 0x06 /* Public */,
-       9,    1,  158,    2, 0x06 /* Public */,
-      10,    2,  161,    2, 0x06 /* Public */,
-      11,    1,  166,    2, 0x06 /* Public */,
-      12,    1,  169,    2, 0x06 /* Public */,
-      13,    1,  172,    2, 0x06 /* Public */,
-      14,    6,  175,    2, 0x06 /* Public */,
-      16,    0,  188,    2, 0x06 /* Public */,
-      17,    1,  189,    2, 0x06 /* Public */,
-      17,    1,  192,    2, 0x06 /* Public */,
+       1,    2,  149,    2, 0x06 /* Public */,
+       5,    1,  154,    2, 0x06 /* Public */,
+       6,    1,  157,    2, 0x06 /* Public */,
+       8,    1,  160,    2, 0x06 /* Public */,
+       9,    1,  163,    2, 0x06 /* Public */,
+      10,    2,  166,    2, 0x06 /* Public */,
+      11,    1,  171,    2, 0x06 /* Public */,
+      12,    2,  174,    2, 0x06 /* Public */,
+      13,    1,  179,    2, 0x06 /* Public */,
+      14,    1,  182,    2, 0x06 /* Public */,
+      15,    6,  185,    2, 0x06 /* Public */,
+      17,    0,  198,    2, 0x06 /* Public */,
+      18,    1,  199,    2, 0x06 /* Public */,
+      18,    1,  202,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      22,    0,  195,    2, 0x0a /* Public */,
-      23,    0,  196,    2, 0x0a /* Public */,
-      24,    6,  197,    2, 0x08 /* Private */,
-      25,    1,  210,    2, 0x08 /* Private */,
-      26,    1,  213,    2, 0x08 /* Private */,
-      27,    1,  216,    2, 0x08 /* Private */,
-      28,    1,  219,    2, 0x08 /* Private */,
-      29,    1,  222,    2, 0x08 /* Private */,
-      30,    0,  225,    2, 0x08 /* Private */,
-      31,    1,  226,    2, 0x08 /* Private */,
-      32,    1,  229,    2, 0x08 /* Private */,
-      33,    0,  232,    2, 0x08 /* Private */,
-      34,    2,  233,    2, 0x08 /* Private */,
+      23,    0,  205,    2, 0x0a /* Public */,
+      24,    0,  206,    2, 0x0a /* Public */,
+      25,    6,  207,    2, 0x08 /* Private */,
+      26,    1,  220,    2, 0x08 /* Private */,
+      27,    1,  223,    2, 0x08 /* Private */,
+      28,    1,  226,    2, 0x08 /* Private */,
+      29,    1,  229,    2, 0x08 /* Private */,
+      30,    1,  232,    2, 0x08 /* Private */,
+      31,    0,  235,    2, 0x08 /* Private */,
+      32,    1,  236,    2, 0x08 /* Private */,
+      33,    1,  239,    2, 0x08 /* Private */,
+      34,    0,  242,    2, 0x08 /* Private */,
+      35,    2,  243,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,
@@ -144,17 +149,18 @@ static const uint qt_meta_data_octave__octave_qscintilla[] = {
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    2,    2,
     QMetaType::Void, QMetaType::QString,    2,
+    QMetaType::Void, QMetaType::QPoint, QMetaType::QString,    2,    2,
     QMetaType::Void, QMetaType::Int,    2,
     QMetaType::Void, QMetaType::Int,    2,
-    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 15, 0x80000000 | 15, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 16, 0x80000000 | 16, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 18,   19,
-    QMetaType::Void, 0x80000000 | 20,   21,
+    QMetaType::Void, 0x80000000 | 19,   20,
+    QMetaType::Void, 0x80000000 | 21,   22,
 
  // slots: parameters
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 15, 0x80000000 | 15, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 16, 0x80000000 | 16, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
@@ -182,25 +188,26 @@ void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Cal
         case 4: _t->qsci_has_focus_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 5: _t->status_update((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
         case 6: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 7: _t->context_menu_break_condition_signal((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 8: _t->context_menu_break_once((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 9: _t->ctx_menu_run_finished_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
-        case 10: _t->focus_console_after_command_signal(); break;
-        case 11: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
-        case 12: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
-        case 13: _t->handle_enter_debug_mode(); break;
-        case 14: _t->handle_exit_debug_mode(); break;
-        case 15: _t->ctx_menu_run_finished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
-        case 16: _t->contextmenu_help((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 17: _t->contextmenu_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 18: _t->contextmenu_help_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 19: _t->contextmenu_edit((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 20: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 21: _t->contextmenu_run_temp_error(); break;
-        case 22: _t->contextmenu_break_condition((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 23: _t->contextmenu_break_once((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 24: _t->text_changed(); break;
-        case 25: _t->cursor_position_changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 7: _t->show_symbol_tooltip_signal((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
+        case 8: _t->context_menu_break_condition_signal((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 9: _t->context_menu_break_once((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 10: _t->ctx_menu_run_finished_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QPointer<QTemporaryFile>(*)>(_a[3])),(*reinterpret_cast< QPointer<QTemporaryFile>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
+        case 11: _t->focus_console_after_command_signal(); break;
+        case 12: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
+        case 13: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
+        case 14: _t->handle_enter_debug_mode(); break;
+        case 15: _t->handle_exit_debug_mode(); break;
+        case 16: _t->ctx_menu_run_finished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QPointer<QTemporaryFile>(*)>(_a[3])),(*reinterpret_cast< QPointer<QTemporaryFile>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
+        case 17: _t->contextmenu_help((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 18: _t->contextmenu_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 19: _t->contextmenu_help_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 20: _t->contextmenu_edit((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 21: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 22: _t->contextmenu_run_temp_error(); break;
+        case 23: _t->contextmenu_break_condition((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 24: _t->contextmenu_break_once((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 25: _t->text_changed(); break;
+        case 26: _t->cursor_position_changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -255,44 +262,51 @@ void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Cal
             }
         }
         {
-            typedef void (octave_qscintilla::*_t)(int );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_condition_signal)) {
+            typedef void (octave_qscintilla::*_t)(const QPoint & , const QString & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::show_symbol_tooltip_signal)) {
                 *result = 7;
                 return;
             }
         }
         {
             typedef void (octave_qscintilla::*_t)(int );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_once)) {
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_condition_signal)) {
                 *result = 8;
                 return;
             }
         }
         {
-            typedef void (octave_qscintilla::*_t)(bool , int , QTemporaryFile * , QTemporaryFile * , bool , bool );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::ctx_menu_run_finished_signal)) {
+            typedef void (octave_qscintilla::*_t)(int );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_once)) {
                 *result = 9;
                 return;
             }
         }
+        {
+            typedef void (octave_qscintilla::*_t)(bool , int , QPointer<QTemporaryFile> , QPointer<QTemporaryFile> , bool , bool );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::ctx_menu_run_finished_signal)) {
+                *result = 10;
+                return;
+            }
+        }
         {
             typedef void (octave_qscintilla::*_t)();
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::focus_console_after_command_signal)) {
-                *result = 10;
+                *result = 11;
                 return;
             }
         }
         {
             typedef void (octave_qscintilla::*_t)(const fcn_callback & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
-                *result = 11;
+                *result = 12;
                 return;
             }
         }
         {
             typedef void (octave_qscintilla::*_t)(const meth_callback & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
-                *result = 12;
+                *result = 13;
                 return;
             }
         }
@@ -324,13 +338,13 @@ int octave::octave_qscintilla::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 26)
+        if (_id < 27)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 26;
+        _id -= 27;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 26)
+        if (_id < 27)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 26;
+        _id -= 27;
     }
     return _id;
 }
@@ -385,44 +399,51 @@ void octave::octave_qscintilla::show_doc_signal(const QString & _t1)
 }
 
 // SIGNAL 7
-void octave::octave_qscintilla::context_menu_break_condition_signal(int _t1)
+void octave::octave_qscintilla::show_symbol_tooltip_signal(const QPoint & _t1, const QString & _t2)
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
     QMetaObject::activate(this, &staticMetaObject, 7, _a);
 }
 
 // SIGNAL 8
-void octave::octave_qscintilla::context_menu_break_once(int _t1)
+void octave::octave_qscintilla::context_menu_break_condition_signal(int _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 8, _a);
 }
 
 // SIGNAL 9
-void octave::octave_qscintilla::ctx_menu_run_finished_signal(bool _t1, int _t2, QTemporaryFile * _t3, QTemporaryFile * _t4, bool _t5, bool _t6)
+void octave::octave_qscintilla::context_menu_break_once(int _t1)
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 9, _a);
 }
 
 // SIGNAL 10
-void octave::octave_qscintilla::focus_console_after_command_signal()
+void octave::octave_qscintilla::ctx_menu_run_finished_signal(bool _t1, int _t2, QPointer<QTemporaryFile> _t3, QPointer<QTemporaryFile> _t4, bool _t5, bool _t6)
 {
-    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
+    QMetaObject::activate(this, &staticMetaObject, 10, _a);
 }
 
 // SIGNAL 11
-void octave::octave_qscintilla::interpreter_event(const fcn_callback & _t1)
+void octave::octave_qscintilla::focus_console_after_command_signal()
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
-    QMetaObject::activate(this, &staticMetaObject, 11, _a);
+    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
 }
 
 // SIGNAL 12
-void octave::octave_qscintilla::interpreter_event(const meth_callback & _t1)
+void octave::octave_qscintilla::interpreter_event(const fcn_callback & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 12, _a);
 }
+
+// SIGNAL 13
+void octave::octave_qscintilla::interpreter_event(const meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 13, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
