@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__documentation_browser_t {
-    QByteArrayData data[13];
-    char stringdata0[168];
+    QByteArrayData data[10];
+    char stringdata0[125];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -40,20 +40,16 @@ QT_MOC_LITERAL(2, 51, 0), // ""
 QT_MOC_LITERAL(3, 52, 3), // "url"
 QT_MOC_LITERAL(4, 56, 7), // "keyword"
 QT_MOC_LITERAL(5, 64, 15), // "notice_settings"
-QT_MOC_LITERAL(6, 80, 19), // "const gui_settings*"
-QT_MOC_LITERAL(7, 100, 8), // "settings"
-QT_MOC_LITERAL(8, 109, 13), // "save_settings"
-QT_MOC_LITERAL(9, 123, 13), // "gui_settings*"
-QT_MOC_LITERAL(10, 137, 7), // "zoom_in"
-QT_MOC_LITERAL(11, 145, 8), // "zoom_out"
-QT_MOC_LITERAL(12, 154, 13) // "zoom_original"
+QT_MOC_LITERAL(6, 80, 13), // "save_settings"
+QT_MOC_LITERAL(7, 94, 7), // "zoom_in"
+QT_MOC_LITERAL(8, 102, 8), // "zoom_out"
+QT_MOC_LITERAL(9, 111, 13) // "zoom_original"
 
     },
     "octave::documentation_browser\0"
     "handle_index_clicked\0\0url\0keyword\0"
-    "notice_settings\0const gui_settings*\0"
-    "settings\0save_settings\0gui_settings*\0"
-    "zoom_in\0zoom_out\0zoom_original"
+    "notice_settings\0save_settings\0zoom_in\0"
+    "zoom_out\0zoom_original"
 };
 #undef QT_MOC_LITERAL
 
@@ -73,17 +69,17 @@ static const uint qt_meta_data_octave__documentation_browser[] = {
  // slots: name, argc, parameters, tag, flags
        1,    2,   49,    2, 0x0a /* Public */,
        1,    1,   54,    2, 0x2a /* Public | MethodCloned */,
-       5,    1,   57,    2, 0x0a /* Public */,
-       8,    1,   60,    2, 0x0a /* Public */,
-      10,    0,   63,    2, 0x0a /* Public */,
-      11,    0,   64,    2, 0x0a /* Public */,
-      12,    0,   65,    2, 0x0a /* Public */,
+       5,    0,   57,    2, 0x0a /* Public */,
+       6,    0,   58,    2, 0x0a /* Public */,
+       7,    0,   59,    2, 0x0a /* Public */,
+       8,    0,   60,    2, 0x0a /* Public */,
+       9,    0,   61,    2, 0x0a /* Public */,
 
  // slots: parameters
     QMetaType::Void, QMetaType::QUrl, QMetaType::QString,    3,    4,
     QMetaType::Void, QMetaType::QUrl,    3,
-    QMetaType::Void, 0x80000000 | 6,    7,
-    QMetaType::Void, 0x80000000 | 9,    7,
+    QMetaType::Void,
+    QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -99,8 +95,8 @@ void octave::documentation_browser::qt_static_metacall(QObject *_o, QMetaObject:
         switch (_id) {
         case 0: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
         case 1: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
-        case 2: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
-        case 3: _t->save_settings((*reinterpret_cast< gui_settings*(*)>(_a[1]))); break;
+        case 2: _t->notice_settings(); break;
+        case 3: _t->save_settings(); break;
         case 4: _t->zoom_in(); break;
         case 5: _t->zoom_out(); break;
         case 6: _t->zoom_original(); break;
@@ -145,8 +141,8 @@ int octave::documentation_browser::qt_metacall(QMetaObject::Call _c, int _id, vo
     return _id;
 }
 struct qt_meta_stringdata_octave__documentation_t {
-    QByteArrayData data[36];
-    char stringdata0[506];
+    QByteArrayData data[34];
+    char stringdata0[477];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -159,46 +155,43 @@ QT_MOC_LITERAL(0, 0, 21), // "octave::documentation"
 QT_MOC_LITERAL(1, 22, 18), // "show_single_result"
 QT_MOC_LITERAL(2, 41, 0), // ""
 QT_MOC_LITERAL(3, 42, 15), // "notice_settings"
-QT_MOC_LITERAL(4, 58, 19), // "const gui_settings*"
-QT_MOC_LITERAL(5, 78, 8), // "settings"
-QT_MOC_LITERAL(6, 87, 13), // "save_settings"
-QT_MOC_LITERAL(7, 101, 13), // "copyClipboard"
-QT_MOC_LITERAL(8, 115, 14), // "pasteClipboard"
-QT_MOC_LITERAL(9, 130, 9), // "selectAll"
-QT_MOC_LITERAL(10, 140, 10), // "load_index"
-QT_MOC_LITERAL(11, 151, 8), // "load_ref"
-QT_MOC_LITERAL(12, 160, 4), // "name"
-QT_MOC_LITERAL(13, 165, 11), // "registerDoc"
-QT_MOC_LITERAL(14, 177, 13), // "unregisterDoc"
-QT_MOC_LITERAL(15, 191, 13), // "activate_find"
-QT_MOC_LITERAL(16, 205, 13), // "global_search"
-QT_MOC_LITERAL(17, 219, 21), // "global_search_started"
-QT_MOC_LITERAL(18, 241, 22), // "global_search_finished"
-QT_MOC_LITERAL(19, 264, 4), // "hits"
-QT_MOC_LITERAL(20, 269, 13), // "filter_update"
-QT_MOC_LITERAL(21, 283, 10), // "expression"
-QT_MOC_LITERAL(22, 294, 21), // "filter_update_history"
-QT_MOC_LITERAL(23, 316, 4), // "find"
-QT_MOC_LITERAL(24, 321, 8), // "backward"
-QT_MOC_LITERAL(25, 330, 13), // "find_backward"
-QT_MOC_LITERAL(26, 344, 24), // "find_forward_from_anchor"
-QT_MOC_LITERAL(27, 369, 4), // "text"
-QT_MOC_LITERAL(28, 374, 22), // "record_anchor_position"
-QT_MOC_LITERAL(29, 397, 29), // "handle_cursor_position_change"
-QT_MOC_LITERAL(30, 427, 28), // "handle_search_result_clicked"
-QT_MOC_LITERAL(31, 456, 3), // "url"
-QT_MOC_LITERAL(32, 460, 20), // "update_history_menus"
-QT_MOC_LITERAL(33, 481, 13), // "open_hist_url"
-QT_MOC_LITERAL(34, 495, 8), // "QAction*"
-QT_MOC_LITERAL(35, 504, 1) // "a"
+QT_MOC_LITERAL(4, 58, 13), // "save_settings"
+QT_MOC_LITERAL(5, 72, 13), // "copyClipboard"
+QT_MOC_LITERAL(6, 86, 14), // "pasteClipboard"
+QT_MOC_LITERAL(7, 101, 9), // "selectAll"
+QT_MOC_LITERAL(8, 111, 10), // "load_index"
+QT_MOC_LITERAL(9, 122, 8), // "load_ref"
+QT_MOC_LITERAL(10, 131, 4), // "name"
+QT_MOC_LITERAL(11, 136, 11), // "registerDoc"
+QT_MOC_LITERAL(12, 148, 13), // "unregisterDoc"
+QT_MOC_LITERAL(13, 162, 13), // "activate_find"
+QT_MOC_LITERAL(14, 176, 13), // "global_search"
+QT_MOC_LITERAL(15, 190, 21), // "global_search_started"
+QT_MOC_LITERAL(16, 212, 22), // "global_search_finished"
+QT_MOC_LITERAL(17, 235, 4), // "hits"
+QT_MOC_LITERAL(18, 240, 13), // "filter_update"
+QT_MOC_LITERAL(19, 254, 10), // "expression"
+QT_MOC_LITERAL(20, 265, 21), // "filter_update_history"
+QT_MOC_LITERAL(21, 287, 4), // "find"
+QT_MOC_LITERAL(22, 292, 8), // "backward"
+QT_MOC_LITERAL(23, 301, 13), // "find_backward"
+QT_MOC_LITERAL(24, 315, 24), // "find_forward_from_anchor"
+QT_MOC_LITERAL(25, 340, 4), // "text"
+QT_MOC_LITERAL(26, 345, 22), // "record_anchor_position"
+QT_MOC_LITERAL(27, 368, 29), // "handle_cursor_position_change"
+QT_MOC_LITERAL(28, 398, 28), // "handle_search_result_clicked"
+QT_MOC_LITERAL(29, 427, 3), // "url"
+QT_MOC_LITERAL(30, 431, 20), // "update_history_menus"
+QT_MOC_LITERAL(31, 452, 13), // "open_hist_url"
+QT_MOC_LITERAL(32, 466, 8), // "QAction*"
+QT_MOC_LITERAL(33, 475, 1) // "a"
 
     },
     "octave::documentation\0show_single_result\0"
-    "\0notice_settings\0const gui_settings*\0"
-    "settings\0save_settings\0copyClipboard\0"
-    "pasteClipboard\0selectAll\0load_index\0"
-    "load_ref\0name\0registerDoc\0unregisterDoc\0"
-    "activate_find\0global_search\0"
+    "\0notice_settings\0save_settings\0"
+    "copyClipboard\0pasteClipboard\0selectAll\0"
+    "load_index\0load_ref\0name\0registerDoc\0"
+    "unregisterDoc\0activate_find\0global_search\0"
     "global_search_started\0global_search_finished\0"
     "hits\0filter_update\0expression\0"
     "filter_update_history\0find\0backward\0"
@@ -228,61 +221,61 @@ static const uint qt_meta_data_octave__documentation[] = {
        1,    1,  144,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       3,    1,  147,    2, 0x0a /* Public */,
+       3,    0,  147,    2, 0x0a /* Public */,
+       4,    0,  148,    2, 0x0a /* Public */,
+       5,    0,  149,    2, 0x0a /* Public */,
        6,    0,  150,    2, 0x0a /* Public */,
        7,    0,  151,    2, 0x0a /* Public */,
        8,    0,  152,    2, 0x0a /* Public */,
-       9,    0,  153,    2, 0x0a /* Public */,
-      10,    0,  154,    2, 0x0a /* Public */,
-      11,    1,  155,    2, 0x0a /* Public */,
-      11,    0,  158,    2, 0x2a /* Public | MethodCloned */,
-      13,    1,  159,    2, 0x0a /* Public */,
-      14,    1,  162,    2, 0x0a /* Public */,
+       9,    1,  153,    2, 0x0a /* Public */,
+       9,    0,  156,    2, 0x2a /* Public | MethodCloned */,
+      11,    1,  157,    2, 0x0a /* Public */,
+      12,    1,  160,    2, 0x0a /* Public */,
+      13,    0,  163,    2, 0x08 /* Private */,
+      14,    0,  164,    2, 0x08 /* Private */,
       15,    0,  165,    2, 0x08 /* Private */,
-      16,    0,  166,    2, 0x08 /* Private */,
-      17,    0,  167,    2, 0x08 /* Private */,
-      18,    1,  168,    2, 0x08 /* Private */,
-      20,    1,  171,    2, 0x08 /* Private */,
-      22,    0,  174,    2, 0x08 /* Private */,
-      23,    1,  175,    2, 0x08 /* Private */,
-      23,    0,  178,    2, 0x28 /* Private | MethodCloned */,
-      25,    0,  179,    2, 0x08 /* Private */,
-      26,    1,  180,    2, 0x08 /* Private */,
-      28,    0,  183,    2, 0x08 /* Private */,
-      29,    0,  184,    2, 0x08 /* Private */,
-      30,    1,  185,    2, 0x08 /* Private */,
-      32,    0,  188,    2, 0x08 /* Private */,
-      33,    1,  189,    2, 0x08 /* Private */,
+      16,    1,  166,    2, 0x08 /* Private */,
+      18,    1,  169,    2, 0x08 /* Private */,
+      20,    0,  172,    2, 0x08 /* Private */,
+      21,    1,  173,    2, 0x08 /* Private */,
+      21,    0,  176,    2, 0x28 /* Private | MethodCloned */,
+      23,    0,  177,    2, 0x08 /* Private */,
+      24,    1,  178,    2, 0x08 /* Private */,
+      26,    0,  181,    2, 0x08 /* Private */,
+      27,    0,  182,    2, 0x08 /* Private */,
+      28,    1,  183,    2, 0x08 /* Private */,
+      30,    0,  186,    2, 0x08 /* Private */,
+      31,    1,  187,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QUrl,    2,
 
  // slots: parameters
-    QMetaType::Void, 0x80000000 | 4,    5,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,   12,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,   12,
-    QMetaType::Void, QMetaType::QString,   12,
+    QMetaType::Void, QMetaType::QString,   10,
+    QMetaType::Void,
+    QMetaType::Void, QMetaType::QString,   10,
+    QMetaType::Void, QMetaType::QString,   10,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Int,   19,
-    QMetaType::Void, QMetaType::QString,   21,
+    QMetaType::Void, QMetaType::Int,   17,
+    QMetaType::Void, QMetaType::QString,   19,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   24,
+    QMetaType::Void, QMetaType::Bool,   22,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,   27,
+    QMetaType::Void, QMetaType::QString,   25,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QUrl,   31,
+    QMetaType::Void, QMetaType::QUrl,   29,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 34,   35,
+    QMetaType::Void, 0x80000000 | 32,   33,
 
        0        // eod
 };
@@ -294,7 +287,7 @@ void octave::documentation::qt_static_metacall(QObject *_o, QMetaObject::Call _c
         Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->show_single_result((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
-        case 1: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 1: _t->notice_settings(); break;
         case 2: _t->save_settings(); break;
         case 3: _t->copyClipboard(); break;
         case 4: _t->pasteClipboard(); break;
