@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__files_dock_widget_t {
-    QByteArrayData data[62];
-    char stringdata0[1073];
+    QByteArrayData data[61];
+    char stringdata0[1065];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -64,38 +64,37 @@ QT_MOC_LITERAL(26, 362, 21), // "set_current_directory"
 QT_MOC_LITERAL(27, 384, 26), // "accept_directory_line_edit"
 QT_MOC_LITERAL(28, 411, 23), // "update_octave_directory"
 QT_MOC_LITERAL(29, 435, 15), // "notice_settings"
-QT_MOC_LITERAL(30, 451, 19), // "const gui_settings*"
-QT_MOC_LITERAL(31, 471, 8), // "settings"
-QT_MOC_LITERAL(32, 480, 13), // "save_settings"
-QT_MOC_LITERAL(33, 494, 27), // "headercontextmenu_requested"
-QT_MOC_LITERAL(34, 522, 3), // "pos"
-QT_MOC_LITERAL(35, 526, 13), // "toggle_header"
-QT_MOC_LITERAL(36, 540, 3), // "col"
-QT_MOC_LITERAL(37, 544, 21), // "contextmenu_requested"
-QT_MOC_LITERAL(38, 566, 16), // "contextmenu_open"
-QT_MOC_LITERAL(39, 583, 26), // "contextmenu_open_in_editor"
-QT_MOC_LITERAL(40, 610, 23), // "contextmenu_open_in_app"
-QT_MOC_LITERAL(41, 634, 26), // "contextmenu_copy_selection"
-QT_MOC_LITERAL(42, 661, 15), // "contextmenu_run"
-QT_MOC_LITERAL(43, 677, 16), // "contextmenu_load"
-QT_MOC_LITERAL(44, 694, 18), // "contextmenu_rename"
-QT_MOC_LITERAL(45, 713, 18), // "contextmenu_delete"
-QT_MOC_LITERAL(46, 732, 19), // "contextmenu_newfile"
-QT_MOC_LITERAL(47, 752, 18), // "contextmenu_newdir"
-QT_MOC_LITERAL(48, 771, 25), // "contextmenu_setcurrentdir"
-QT_MOC_LITERAL(49, 797, 23), // "contextmenu_add_to_path"
-QT_MOC_LITERAL(50, 821, 31), // "contextmenu_add_to_path_subdirs"
-QT_MOC_LITERAL(51, 853, 24), // "contextmenu_rm_from_path"
-QT_MOC_LITERAL(52, 878, 32), // "contextmenu_rm_from_path_subdirs"
-QT_MOC_LITERAL(53, 911, 21), // "contextmenu_findfiles"
-QT_MOC_LITERAL(54, 933, 19), // "popdownmenu_newfile"
-QT_MOC_LITERAL(55, 953, 18), // "popdownmenu_newdir"
-QT_MOC_LITERAL(56, 972, 22), // "popdownmenu_search_dir"
-QT_MOC_LITERAL(57, 995, 21), // "popdownmenu_findfiles"
-QT_MOC_LITERAL(58, 1017, 16), // "popdownmenu_home"
-QT_MOC_LITERAL(59, 1034, 13), // "copyClipboard"
-QT_MOC_LITERAL(60, 1048, 14), // "pasteClipboard"
-QT_MOC_LITERAL(61, 1063, 9) // "selectAll"
+QT_MOC_LITERAL(30, 451, 13), // "save_settings"
+QT_MOC_LITERAL(31, 465, 20), // "restore_header_state"
+QT_MOC_LITERAL(32, 486, 27), // "headercontextmenu_requested"
+QT_MOC_LITERAL(33, 514, 3), // "pos"
+QT_MOC_LITERAL(34, 518, 13), // "toggle_header"
+QT_MOC_LITERAL(35, 532, 3), // "col"
+QT_MOC_LITERAL(36, 536, 21), // "contextmenu_requested"
+QT_MOC_LITERAL(37, 558, 16), // "contextmenu_open"
+QT_MOC_LITERAL(38, 575, 26), // "contextmenu_open_in_editor"
+QT_MOC_LITERAL(39, 602, 23), // "contextmenu_open_in_app"
+QT_MOC_LITERAL(40, 626, 26), // "contextmenu_copy_selection"
+QT_MOC_LITERAL(41, 653, 15), // "contextmenu_run"
+QT_MOC_LITERAL(42, 669, 16), // "contextmenu_load"
+QT_MOC_LITERAL(43, 686, 18), // "contextmenu_rename"
+QT_MOC_LITERAL(44, 705, 18), // "contextmenu_delete"
+QT_MOC_LITERAL(45, 724, 19), // "contextmenu_newfile"
+QT_MOC_LITERAL(46, 744, 18), // "contextmenu_newdir"
+QT_MOC_LITERAL(47, 763, 25), // "contextmenu_setcurrentdir"
+QT_MOC_LITERAL(48, 789, 23), // "contextmenu_add_to_path"
+QT_MOC_LITERAL(49, 813, 31), // "contextmenu_add_to_path_subdirs"
+QT_MOC_LITERAL(50, 845, 24), // "contextmenu_rm_from_path"
+QT_MOC_LITERAL(51, 870, 32), // "contextmenu_rm_from_path_subdirs"
+QT_MOC_LITERAL(52, 903, 21), // "contextmenu_findfiles"
+QT_MOC_LITERAL(53, 925, 19), // "popdownmenu_newfile"
+QT_MOC_LITERAL(54, 945, 18), // "popdownmenu_newdir"
+QT_MOC_LITERAL(55, 964, 22), // "popdownmenu_search_dir"
+QT_MOC_LITERAL(56, 987, 21), // "popdownmenu_findfiles"
+QT_MOC_LITERAL(57, 1009, 16), // "popdownmenu_home"
+QT_MOC_LITERAL(58, 1026, 13), // "copyClipboard"
+QT_MOC_LITERAL(59, 1040, 14), // "pasteClipboard"
+QT_MOC_LITERAL(60, 1055, 9) // "selectAll"
 
     },
     "octave::files_dock_widget\0open_file\0"
@@ -111,7 +110,7 @@ QT_MOC_LITERAL(61, 1063, 9) // "selectAll"
     "do_sync_browser_directory\0"
     "set_current_directory\0accept_directory_line_edit\0"
     "update_octave_directory\0notice_settings\0"
-    "const gui_settings*\0settings\0save_settings\0"
+    "save_settings\0restore_header_state\0"
     "headercontextmenu_requested\0pos\0"
     "toggle_header\0col\0contextmenu_requested\0"
     "contextmenu_open\0contextmenu_open_in_editor\0"
@@ -137,7 +136,7 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      47,   14, // methods
+      48,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -145,55 +144,56 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
        9,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  249,    2, 0x06 /* Public */,
-       4,    1,  252,    2, 0x06 /* Public */,
-       6,    1,  255,    2, 0x06 /* Public */,
-       7,    1,  258,    2, 0x06 /* Public */,
-       8,    1,  261,    2, 0x06 /* Public */,
-      11,    1,  264,    2, 0x06 /* Public */,
-      13,    2,  267,    2, 0x06 /* Public */,
-      16,    1,  272,    2, 0x06 /* Public */,
-      17,    3,  275,    2, 0x06 /* Public */,
+       1,    1,  254,    2, 0x06 /* Public */,
+       4,    1,  257,    2, 0x06 /* Public */,
+       6,    1,  260,    2, 0x06 /* Public */,
+       7,    1,  263,    2, 0x06 /* Public */,
+       8,    1,  266,    2, 0x06 /* Public */,
+      11,    1,  269,    2, 0x06 /* Public */,
+      13,    2,  272,    2, 0x06 /* Public */,
+      16,    1,  277,    2, 0x06 /* Public */,
+      17,    3,  280,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      21,    1,  282,    2, 0x0a /* Public */,
-      23,    0,  285,    2, 0x0a /* Public */,
-      24,    0,  286,    2, 0x0a /* Public */,
-      25,    0,  287,    2, 0x0a /* Public */,
-      26,    1,  288,    2, 0x0a /* Public */,
-      27,    0,  291,    2, 0x0a /* Public */,
-      28,    1,  292,    2, 0x0a /* Public */,
-      29,    1,  295,    2, 0x0a /* Public */,
-      32,    0,  298,    2, 0x0a /* Public */,
-      33,    1,  299,    2, 0x08 /* Private */,
-      35,    1,  302,    2, 0x08 /* Private */,
-      37,    1,  305,    2, 0x08 /* Private */,
-      38,    1,  308,    2, 0x08 /* Private */,
-      39,    1,  311,    2, 0x08 /* Private */,
-      40,    1,  314,    2, 0x08 /* Private */,
-      41,    1,  317,    2, 0x08 /* Private */,
-      42,    1,  320,    2, 0x08 /* Private */,
-      43,    1,  323,    2, 0x08 /* Private */,
-      44,    1,  326,    2, 0x08 /* Private */,
-      45,    1,  329,    2, 0x08 /* Private */,
-      46,    1,  332,    2, 0x08 /* Private */,
-      47,    1,  335,    2, 0x08 /* Private */,
-      48,    1,  338,    2, 0x08 /* Private */,
-      49,    3,  341,    2, 0x08 /* Private */,
-      49,    2,  348,    2, 0x28 /* Private | MethodCloned */,
-      49,    1,  353,    2, 0x28 /* Private | MethodCloned */,
-      50,    1,  356,    2, 0x08 /* Private */,
-      51,    1,  359,    2, 0x08 /* Private */,
-      52,    1,  362,    2, 0x08 /* Private */,
-      53,    1,  365,    2, 0x08 /* Private */,
-      54,    1,  368,    2, 0x08 /* Private */,
-      55,    1,  371,    2, 0x08 /* Private */,
-      56,    1,  374,    2, 0x08 /* Private */,
-      57,    1,  377,    2, 0x08 /* Private */,
-      58,    1,  380,    2, 0x08 /* Private */,
-      59,    0,  383,    2, 0x08 /* Private */,
-      60,    0,  384,    2, 0x08 /* Private */,
-      61,    0,  385,    2, 0x08 /* Private */,
+      21,    1,  287,    2, 0x0a /* Public */,
+      23,    0,  290,    2, 0x0a /* Public */,
+      24,    0,  291,    2, 0x0a /* Public */,
+      25,    0,  292,    2, 0x0a /* Public */,
+      26,    1,  293,    2, 0x0a /* Public */,
+      27,    0,  296,    2, 0x0a /* Public */,
+      28,    1,  297,    2, 0x0a /* Public */,
+      29,    0,  300,    2, 0x0a /* Public */,
+      30,    0,  301,    2, 0x0a /* Public */,
+      31,    0,  302,    2, 0x08 /* Private */,
+      32,    1,  303,    2, 0x08 /* Private */,
+      34,    1,  306,    2, 0x08 /* Private */,
+      36,    1,  309,    2, 0x08 /* Private */,
+      37,    1,  312,    2, 0x08 /* Private */,
+      38,    1,  315,    2, 0x08 /* Private */,
+      39,    1,  318,    2, 0x08 /* Private */,
+      40,    1,  321,    2, 0x08 /* Private */,
+      41,    1,  324,    2, 0x08 /* Private */,
+      42,    1,  327,    2, 0x08 /* Private */,
+      43,    1,  330,    2, 0x08 /* Private */,
+      44,    1,  333,    2, 0x08 /* Private */,
+      45,    1,  336,    2, 0x08 /* Private */,
+      46,    1,  339,    2, 0x08 /* Private */,
+      47,    1,  342,    2, 0x08 /* Private */,
+      48,    3,  345,    2, 0x08 /* Private */,
+      48,    2,  352,    2, 0x28 /* Private | MethodCloned */,
+      48,    1,  357,    2, 0x28 /* Private | MethodCloned */,
+      49,    1,  360,    2, 0x08 /* Private */,
+      50,    1,  363,    2, 0x08 /* Private */,
+      51,    1,  366,    2, 0x08 /* Private */,
+      52,    1,  369,    2, 0x08 /* Private */,
+      53,    1,  372,    2, 0x08 /* Private */,
+      54,    1,  375,    2, 0x08 /* Private */,
+      55,    1,  378,    2, 0x08 /* Private */,
+      56,    1,  381,    2, 0x08 /* Private */,
+      57,    1,  384,    2, 0x08 /* Private */,
+      58,    0,  387,    2, 0x08 /* Private */,
+      59,    0,  388,    2, 0x08 /* Private */,
+      60,    0,  389,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
@@ -214,11 +214,12 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
     QMetaType::Void, QMetaType::QString,    5,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
-    QMetaType::Void, 0x80000000 | 30,   31,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QPoint,   34,
-    QMetaType::Void, QMetaType::Int,   36,
-    QMetaType::Void, QMetaType::QPoint,   34,
+    QMetaType::Void,
+    QMetaType::Void,
+    QMetaType::Void, QMetaType::QPoint,   33,
+    QMetaType::Void, QMetaType::Int,   35,
+    QMetaType::Void, QMetaType::QPoint,   33,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
@@ -271,37 +272,38 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
         case 13: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 14: _t->accept_directory_line_edit(); break;
         case 15: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 16: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 16: _t->notice_settings(); break;
         case 17: _t->save_settings(); break;
-        case 18: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 19: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 20: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 21: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 22: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 23: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 24: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 25: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 26: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 27: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 28: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 29: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 30: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 31: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 32: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
-        case 33: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
-        case 34: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 35: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 36: _t->contextmenu_rm_from_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 37: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 38: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 39: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 40: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 41: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 42: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 43: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 44: _t->copyClipboard(); break;
-        case 45: _t->pasteClipboard(); break;
-        case 46: _t->selectAll(); break;
+        case 18: _t->restore_header_state(); break;
+        case 19: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 20: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 21: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 22: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 23: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 24: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 25: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 26: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 27: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 28: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 29: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 30: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 31: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 32: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 33: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
+        case 34: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
+        case 35: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 36: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 37: _t->contextmenu_rm_from_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 38: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 39: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 40: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 41: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 42: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 43: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 44: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 45: _t->copyClipboard(); break;
+        case 46: _t->pasteClipboard(); break;
+        case 47: _t->selectAll(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -397,13 +399,13 @@ int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 47)
+        if (_id < 48)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 47;
+        _id -= 48;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 47)
+        if (_id < 48)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 47;
+        _id -= 48;
     }
     return _id;
 }
