@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__qt_interpreter_events_t {
-    QByteArrayData data[77];
-    char stringdata0[1358];
+    QByteArrayData data[76];
+    char stringdata0[1338];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -106,11 +106,10 @@ QT_MOC_LITERAL(68, 1161, 30), // "refresh_variable_editor_signal"
 QT_MOC_LITERAL(69, 1192, 23), // "confirm_shutdown_signal"
 QT_MOC_LITERAL(70, 1216, 21), // "get_named_icon_signal"
 QT_MOC_LITERAL(71, 1238, 16), // "settings_changed"
-QT_MOC_LITERAL(72, 1255, 19), // "const gui_settings*"
-QT_MOC_LITERAL(73, 1275, 18), // "apply_new_settings"
-QT_MOC_LITERAL(74, 1294, 23), // "confirm_shutdown_octave"
-QT_MOC_LITERAL(75, 1318, 19), // "get_named_icon_slot"
-QT_MOC_LITERAL(76, 1338, 19) // "gui_preference_slot"
+QT_MOC_LITERAL(72, 1255, 18), // "apply_new_settings"
+QT_MOC_LITERAL(73, 1274, 23), // "confirm_shutdown_octave"
+QT_MOC_LITERAL(74, 1298, 19), // "get_named_icon_slot"
+QT_MOC_LITERAL(75, 1318, 19) // "gui_preference_slot"
 
     },
     "octave::qt_interpreter_events\0"
@@ -149,9 +148,9 @@ QT_MOC_LITERAL(76, 1338, 19) // "gui_preference_slot"
     "name\0octave_value\0val\0"
     "refresh_variable_editor_signal\0"
     "confirm_shutdown_signal\0get_named_icon_signal\0"
-    "settings_changed\0const gui_settings*\0"
-    "apply_new_settings\0confirm_shutdown_octave\0"
-    "get_named_icon_slot\0gui_preference_slot"
+    "settings_changed\0apply_new_settings\0"
+    "confirm_shutdown_octave\0get_named_icon_slot\0"
+    "gui_preference_slot"
 };
 #undef QT_MOC_LITERAL
 
@@ -210,13 +209,13 @@ static const uint qt_meta_data_octave__qt_interpreter_events[] = {
       68,    0,  356,    2, 0x06 /* Public */,
       69,    0,  357,    2, 0x06 /* Public */,
       70,    1,  358,    2, 0x06 /* Public */,
-      71,    2,  361,    2, 0x06 /* Public */,
-      73,    0,  366,    2, 0x06 /* Public */,
+      71,    1,  361,    2, 0x06 /* Public */,
+      72,    0,  364,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      74,    0,  367,    2, 0x0a /* Public */,
-      75,    1,  368,    2, 0x0a /* Public */,
-      76,    2,  371,    2, 0x0a /* Public */,
+      73,    0,  365,    2, 0x0a /* Public */,
+      74,    1,  366,    2, 0x0a /* Public */,
+      75,    2,  369,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::Bool,    3,
@@ -260,7 +259,7 @@ static const uint qt_meta_data_octave__qt_interpreter_events[] = {
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,   65,
-    QMetaType::Void, 0x80000000 | 72, QMetaType::Bool,    2,    2,
+    QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void,
 
  // slots: parameters
@@ -318,7 +317,7 @@ void octave::qt_interpreter_events::qt_static_metacall(QObject *_o, QMetaObject:
         case 38: _t->refresh_variable_editor_signal(); break;
         case 39: _t->confirm_shutdown_signal(); break;
         case 40: _t->get_named_icon_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 41: _t->settings_changed((*reinterpret_cast< const gui_settings*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
+        case 41: _t->settings_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 42: _t->apply_new_settings(); break;
         case 43: _t->confirm_shutdown_octave(); break;
         case 44: _t->get_named_icon_slot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
@@ -608,7 +607,7 @@ void octave::qt_interpreter_events::qt_static_metacall(QObject *_o, QMetaObject:
             }
         }
         {
-            typedef void (qt_interpreter_events::*_t)(const gui_settings * , bool );
+            typedef void (qt_interpreter_events::*_t)(bool );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::settings_changed)) {
                 *result = 41;
                 return;
@@ -929,9 +928,9 @@ void octave::qt_interpreter_events::get_named_icon_signal(const QString & _t1)
 }
 
 // SIGNAL 41
-void octave::qt_interpreter_events::settings_changed(const gui_settings * _t1, bool _t2)
+void octave::qt_interpreter_events::settings_changed(bool _t1)
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 41, _a);
 }
 
