@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2011-2023 The Octave Project Developers
+// Copyright (C) 2011-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,21 +33,19 @@ class QTextBrowser;
 
 namespace octave {
 
-class base_qobject;
-
 class release_notes : public QWidget
 {
   Q_OBJECT
 
 public:
 
-  release_notes (base_qobject& qct_qobj);
+  release_notes ();
 
-  ~release_notes (void) = default;
+  ~release_notes () = default;
 
 public slots:
 
-  void display (void);
+  void display ();
 
 private:
 
