@@ -936,8 +936,8 @@ void octave::ReturnFocusMenu::about_to_activate()
     QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
 }
 struct qt_meta_stringdata_octave__variable_editor_t {
-    QByteArrayData data[37];
-    char stringdata0[510];
+    QByteArrayData data[36];
+    char stringdata0[490];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -966,23 +966,22 @@ QT_MOC_LITERAL(16, 228, 13), // "meth_callback"
 QT_MOC_LITERAL(17, 242, 4), // "meth"
 QT_MOC_LITERAL(18, 247, 10), // "callUpdate"
 QT_MOC_LITERAL(19, 258, 15), // "notice_settings"
-QT_MOC_LITERAL(20, 274, 19), // "const gui_settings*"
-QT_MOC_LITERAL(21, 294, 13), // "edit_variable"
-QT_MOC_LITERAL(22, 308, 4), // "name"
-QT_MOC_LITERAL(23, 313, 12), // "octave_value"
-QT_MOC_LITERAL(24, 326, 3), // "val"
-QT_MOC_LITERAL(25, 330, 18), // "variable_destroyed"
-QT_MOC_LITERAL(26, 349, 3), // "obj"
-QT_MOC_LITERAL(27, 353, 16), // "variable_focused"
-QT_MOC_LITERAL(28, 370, 29), // "record_hovered_focus_variable"
-QT_MOC_LITERAL(29, 400, 30), // "restore_hovered_focus_variable"
-QT_MOC_LITERAL(30, 431, 10), // "closeEvent"
-QT_MOC_LITERAL(31, 442, 12), // "QCloseEvent*"
-QT_MOC_LITERAL(32, 455, 4), // "save"
-QT_MOC_LITERAL(33, 460, 12), // "cutClipboard"
-QT_MOC_LITERAL(34, 473, 13), // "copyClipboard"
-QT_MOC_LITERAL(35, 487, 14), // "pasteClipboard"
-QT_MOC_LITERAL(36, 502, 7) // "levelUp"
+QT_MOC_LITERAL(20, 274, 13), // "edit_variable"
+QT_MOC_LITERAL(21, 288, 4), // "name"
+QT_MOC_LITERAL(22, 293, 12), // "octave_value"
+QT_MOC_LITERAL(23, 306, 3), // "val"
+QT_MOC_LITERAL(24, 310, 18), // "variable_destroyed"
+QT_MOC_LITERAL(25, 329, 3), // "obj"
+QT_MOC_LITERAL(26, 333, 16), // "variable_focused"
+QT_MOC_LITERAL(27, 350, 29), // "record_hovered_focus_variable"
+QT_MOC_LITERAL(28, 380, 30), // "restore_hovered_focus_variable"
+QT_MOC_LITERAL(29, 411, 10), // "closeEvent"
+QT_MOC_LITERAL(30, 422, 12), // "QCloseEvent*"
+QT_MOC_LITERAL(31, 435, 4), // "save"
+QT_MOC_LITERAL(32, 440, 12), // "cutClipboard"
+QT_MOC_LITERAL(33, 453, 13), // "copyClipboard"
+QT_MOC_LITERAL(34, 467, 14), // "pasteClipboard"
+QT_MOC_LITERAL(35, 482, 7) // "levelUp"
 
     },
     "octave::variable_editor\0updated\0\0"
@@ -992,10 +991,9 @@ QT_MOC_LITERAL(36, 502, 7) // "levelUp"
     "save_signal\0delete_selected_signal\0"
     "interpreter_event\0fcn_callback\0fcn\0"
     "meth_callback\0meth\0callUpdate\0"
-    "notice_settings\0const gui_settings*\0"
-    "edit_variable\0name\0octave_value\0val\0"
-    "variable_destroyed\0obj\0variable_focused\0"
-    "record_hovered_focus_variable\0"
+    "notice_settings\0edit_variable\0name\0"
+    "octave_value\0val\0variable_destroyed\0"
+    "obj\0variable_focused\0record_hovered_focus_variable\0"
     "restore_hovered_focus_variable\0"
     "closeEvent\0QCloseEvent*\0save\0cutClipboard\0"
     "copyClipboard\0pasteClipboard\0levelUp"
@@ -1031,18 +1029,18 @@ static const uint qt_meta_data_octave__variable_editor[] = {
 
  // slots: name, argc, parameters, tag, flags
       18,    2,  157,    2, 0x0a /* Public */,
-      19,    1,  162,    2, 0x0a /* Public */,
-      21,    2,  165,    2, 0x0a /* Public */,
-      25,    1,  170,    2, 0x0a /* Public */,
-      27,    1,  173,    2, 0x0a /* Public */,
-      28,    0,  176,    2, 0x0a /* Public */,
-      29,    0,  177,    2, 0x0a /* Public */,
-      30,    1,  178,    2, 0x09 /* Protected */,
-      32,    0,  181,    2, 0x09 /* Protected */,
-      33,    0,  182,    2, 0x09 /* Protected */,
-      34,    0,  183,    2, 0x09 /* Protected */,
-      35,    0,  184,    2, 0x09 /* Protected */,
-      36,    0,  185,    2, 0x09 /* Protected */,
+      19,    0,  162,    2, 0x0a /* Public */,
+      20,    2,  163,    2, 0x0a /* Public */,
+      24,    1,  168,    2, 0x0a /* Public */,
+      26,    1,  171,    2, 0x0a /* Public */,
+      27,    0,  174,    2, 0x0a /* Public */,
+      28,    0,  175,    2, 0x0a /* Public */,
+      29,    1,  176,    2, 0x09 /* Protected */,
+      31,    0,  179,    2, 0x09 /* Protected */,
+      32,    0,  180,    2, 0x09 /* Protected */,
+      33,    0,  181,    2, 0x09 /* Protected */,
+      34,    0,  182,    2, 0x09 /* Protected */,
+      35,    0,  183,    2, 0x09 /* Protected */,
 
  // signals: parameters
     QMetaType::Void,
@@ -1060,13 +1058,13 @@ static const uint qt_meta_data_octave__variable_editor[] = {
 
  // slots: parameters
     QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
-    QMetaType::Void, 0x80000000 | 20,    2,
-    QMetaType::Void, QMetaType::QString, 0x80000000 | 23,   22,   24,
-    QMetaType::Void, QMetaType::QObjectStar,   26,
-    QMetaType::Void, QMetaType::QString,   22,
+    QMetaType::Void,
+    QMetaType::Void, QMetaType::QString, 0x80000000 | 22,   21,   23,
+    QMetaType::Void, QMetaType::QObjectStar,   25,
+    QMetaType::Void, QMetaType::QString,   21,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 31,    2,
+    QMetaType::Void, 0x80000000 | 30,    2,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -1095,7 +1093,7 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 10: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
         case 11: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
         case 12: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
-        case 13: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 13: _t->notice_settings(); break;
         case 14: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
         case 15: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
         case 16: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
